
from swiginac import *
from SyFi import *


def compute_divergence_constraint(v_element, p_element, G, D): 
    B = {}
    for i in range(0,v_element.nbf()): 
        for j in range(0,p_element.nbf()): 
            integrand = div(v_element.N(i))*p_element.N(j)
            B[i,j] =  polygon.integrate(integrand)*D
    return B 


def code_for_divergence_constraint(B):
    B_string = ""
    keys = B.keys()
    keys.sort(integer_sequence_compare)

    for key in keys: 
        i,j = key 
        B_string += "  B[%d][%d] = %s;\n" % (i,j,B[i,j].evalf().printc())

    return B_string
 



def integer_sequence_compare(seq1, seq2):
    if not len(seq1) == len(seq2):  
        return len(seq1) - len(seq2)

    for i in range(0,len(seq1)):  
        if not seq1[i] == seq2[i]:  
            return seq1[i] - seq2[i]


initialization_on_2D_triangle = """
  double x0 = pp0[0]; double y0 = pp0[1];
  double x1 = pp1[0]; double y1 = pp1[1];
  double x2 = pp2[0]; double y2 = pp2[1];

  double G00 = x1 - x0;
  double G01 = x2 - x0;

  double G10 = y1 - y0;
  double G11 = y2 - y0;

  double D = fabs(G00*G11-G01*G10);

  double Jinv00 = 1.0/(G00*G11-G10*G01)*G11;
  double Jinv01 = -1.0*1.0/(G00*G11-G10*G01)*G10;
  double Jinv10 = -1.0*1.0/(G00*G11-G10*G01)*G01;
  double Jinv11 = 1.0/(G00*G11-G10*G01)*G00;
"""


polygon = ReferenceTriangle()
v_element = VectorLagrangeFE(polygon,2)
v_element.set_size(2)
v_element.compute_basis_functions()

p_element = LagrangeFE(polygon,1)
p_element.compute_basis_functions()

G = symbolic_matrix(2,2,"G");
x0 = symbol("x0"); y0 = symbol("y0"); 
p0 = matrix(2,1,[x0, y0]) 
D = symbol("D")


B = compute_divergence_constraint(v_element, p_element, G, D)
B_string = code_for_divergence_constraint(B)



cfile = open("div_matrix_taylorhood.cc", 'w')
code = """
void compute_div_matrix(double B[%d,%d], double pp0[2], 
                        double pp1[2], double pp2[2]) {  
%s
%s
}
"""% (v_element.nbf(), p_element.nbf(), initialization_on_2D_triangle, B_string)  

    
cfile.write( code) 
cfile.close()
       



