#ifndef MatrixFactory_MxElasticity_h_IS_INCLUDED
#define MatrixFactory_MxElasticity_h_IS_INCLUDED

#include <dolfin.h>
#include <utility>
#include <map>
#include <iostream>
#include <fstream>
#include "TensorFunction.h"
#include "FastMatSparse.h"
#include "Dof_ptv.h"
#include "Dof_simplex.h"
#include "ScalarFunction.h"
#include "VectorFunction.h"

#include <ml_config.h>
#ifdef HAVE_ML_EPETRA 
#ifdef HAVE_MPI
#include "mpi.h"
#include "Epetra_MpiComm.h"
#else
#include "Epetra_SerialComm.h"
#endif
#include <Epetra_Map.h>
#include <Epetra_FECrsMatrix.h>
#include <Epetra_ConfigDefs.h>
#endif // HAVE_ML_EPETRA 


/*
 * TODO: 
 * Have not used the Piola mapping and have not cared about the sign 
 * related to the normal vector. 
 *
 * More critical is the handeling of essential bondary conditions in geneneral.
 * Should I generate a function approximately on the form:  
 *
 * double essBC(int glob_dof, some_function ) {
 *
 *     From glob_dof I can fetch the local dof and the element. 
 *     
 *     Then the function should be evaluated as needed, e.g.,  
 *     integral_some_edge (some_function*some_moment)
 *
 *     where some_edge and some_moment is obtained from the local dof. 
 *
 * }
 *
 */


namespace pycc {

// forward declaration
class MapMatrixFactory; 


class MatrixFactory 
{
    public:
        MapMatrixFactory   *mapfac; 
	dolfin::Mesh       *mesh;
        Dof_simplex_i      *idof; 
        Dof_ptv            *jdof; 
        int order1; 
        int order2; 

        MatrixFactory(dolfin::Mesh *_mesh);
        ~MatrixFactory();

        FastMatSparse*  computeSigmaMassMatrix(bool append_to_matrix=false);
        FastMatSparse*  computePxSigmaMassMatrix(bool append_to_matrix=false);
        FastMatSparse*  computeUxDivSigmaMatrix(bool append_to_matrix=false);
};





class MapMatrixFactory 
{
    public:
	dolfin::Mesh *mesh;
        Dof_simplex_i  *idof; 
        Dof_ptv *jdof; 
        std::map<std::pair<int,int>,double> *matrix;
        std::map<int,double>            *rhs; 
        int order1; 
        int order2; 


        MapMatrixFactory(dolfin::Mesh *_mesh);
        ~MapMatrixFactory();

        void computeSigmaMassMatrix(bool append_to_matrix=false);
        void computePxSigmaMassMatrix(bool append_to_matrix=false);
        void computeUxDivSigmaMatrix(bool append_to_matrix=false);
};


void dump_to_matlab(std::map<std::pair<int,int>,double> A, const char *varname, const char *s);


#ifdef HAVE_ML_EPETRA


class EpetraMatrixFactory 
{
    public:

        Epetra_Comm       *Comm; 
        Epetra_Map        *Map; 
        MapMatrixFactory  *mapfac; 
	dolfin::Mesh      *mesh;
        Dof_simplex_i     *idof; 
        Dof_ptv           *jdof; 
        int order1; 
        int order2; 

        EpetraMatrixFactory(dolfin::Mesh *_mesh, Epetra_Comm* Comm);
        ~EpetraMatrixFactory();

        Epetra_CrsMatrix*  computeSigmaMassMatrix(bool append_to_matrix=false);
        Epetra_CrsMatrix*  computePxSigmaMassMatrix(bool append_to_matrix=false);
        Epetra_CrsMatrix*  computeUxDivSigmaMatrix(bool append_to_matrix=false);

};


Epetra_CrsMatrix* map2epetra(map<std::pair<int,int>,double>& A_from, Epetra_Map& emap);

#endif // HAVE_ML_EPETRA

}


#endif 
