
from swiginac import *
from SyFi import *

def geometry_string_3D():
  s = """
  double x0 = pp0[0]; double y0 = pp0[1]; double z0 = pp0[2];
  double x1 = pp1[0]; double y1 = pp1[1]; double z1 = pp1[2];
  double x2 = pp2[0]; double y2 = pp2[1]; double z2 = pp2[2];
  double x3 = pp3[0]; double y3 = pp3[1]; double z3 = pp3[2];

  double G00 = x1 - x0;
  double G10 = y1 - y0;
  double G20 = z1 - z0;

  double G01 = x2 - x0;
  double G11 = y2 - y0;
  double G21 = z2 - z0;

  double G02 = x3 - x0;
  double G12 = y3 - y0;
  double G22 = z3 - z0;

  double D =  G00*(G11*G22-G21*G12)
            - G01*(G10*G22-G20*G12)
            + G02*(G10*G21-G20*G11);



"""
  return s


def create_header():
  s = """
#include <math.h>
#include <utility>
#include <map>
#include <ptv.h>
#include <simplex.h>
#include "DofT.h"
#include <ScalarFunction.h>
#include <VectorFunction.h>

using namespace std;

namespace pycc {

"""
  return s

def create_tail():
  s = """
} // namespace pycc
"""
  return s




def find_points_and_ints(dof):
    points =[]
    ints= []
    for d in range(0,len(dof)):
        curr = dof[d]
        if isinstance(curr,list): 
            for d2 in range(0,len(curr)):
                curr2 = curr[d2] 
                if isinstance(curr2,list): 
                    points.append(curr2) 
                else: 
                    ints.append(curr2)
        else: 
            ints.append(curr)
    return (points, ints)


def create_vector_dof_string(fe,G,p0,prefix="i",dofprefix=""):
  nsd = p0.nops()
  D_str =""
  D_str += "  int    i%s_dof[%d];\n"%(prefix,fe.nbf())
  for i in range(0,fe.nbf()):
    dofi = fe.dof(i)
    dofi0 = dofi[0][0][0]
    dofi1 = dofi[0][0][1]
    dofi2 = dofi[0][1]
    dofm = matrix(1,nsd,dofi0)
    gdofm = G.mul(dofm.transpose()).add(p0)
    D_str += "  double %sdof%d[%d];\n"%(prefix,i,nsd+2)
    for d in range(0,nsd):
      D_str +=  "  %sdof%d[%d]=%s;"%(prefix,i,d,gdofm.op(d).printc())
    D_str += "\n  %sdof%d[%d] = %s;" %  (prefix,i,nsd,dofi1.printc())
    D_str += " %sdof%d[%d] = %s;" %  (prefix,i,nsd+1,"element")
    D_str += "\n  ptv %spdof%d(%d,%sdof%d);\n"%(prefix,i,nsd+2,prefix,i)
    D_str += "  i%s_dof[%d] = %s_dof.insert_dof(element,%d,%spdof%d);\n\n"%(prefix,i,dofprefix,i,prefix,i)

  return D_str







def create_tensor_dof_string(fe, G, p0, prefix=""):  
	ptvs = {}
	ptv_counter = 0 
	simplices = {}
	simplices_counter = 0 
	dof_map = {}
	for i in range(0, fe.nbf()): 
	    dof = fe.dof(i)
		
	    points, ints = find_points_and_ints(dof) 
	    global_points = []
	    for p in points:  
		tmp = matrix(1,3,p)
		global_points.append(G.mul(tmp.transpose()).add(p0))

	    for g in global_points:  
		if ptvs.has_key(str(g)):  
		    ptvs[str(g)][1] += 1 
		else: 
		    ptvs[str(g)] = [ptv_counter, 1, g] 
		    ptv_counter += 1 


	    if simplices.has_key(str(global_points)):
		simplices[str(global_points)][1] += 1 
	    else: 
		tmp = []
		for g in global_points: 
		    tmp.append(ptvs[str(g)][0])
		simplices[str(global_points)] = [ simplices_counter, 1, tmp]
							
		simplices_counter += 1 
	    

	    dof_map[i] = [simplices[str(global_points)],ints]


	ptv_str = ""
	counter1 = 0 
	for pp in ptvs.keys(): 
	    g = ptvs[pp][2]
	    ptv_str += "  double dptv%d[3];\n"%counter1    
	    counter2 = 0 
	    for i in range(0,g.nops()):  
		ptv_str += "  dptv%d[%d] = %s;\n"%(counter1,i,g.op(i)) 

            ptv_str += "  ptv ptv%d(3,dptv%d);\n"%(counter1,counter1)		
	    ptv_str += "\n"
	    counter1 += 1 


	simplex_str  = "" 
	simplices_counter = 0 
	for s in simplices.keys(): 
	    tmp_str = ""
	    for i in range(0,len(simplices[s][2])-1): 
		tmp_str += "ptv%d, "% simplices[s][2][i] 
	    tmp_str += "ptv%d"% simplices[s][2][len(simplices[s][2])-1] 

	    simplex_str += "  simplex s%d(%s);\n" %(simplices_counter, tmp_str)   
	    simplices_counter += 1 

	simplex_str += "\n"



	dof_str = ""
	dof_str += "  int i%s_dof[%d];" % (prefix,fe.nbf())
	for i in dof_map.keys(): 
	    dof = dof_map[i]
	    dof_str += "  simplex_i dof%d(s%d,%d,%d);\n" % (i,dof[0][0], dof[1][0], dof[1][1]) 
            dof_str += "  i%s_dof[%d] = %s_dof.insert_dof(element, %d, dof%d);\n" % (prefix,i,prefix,i,i)		

	dof_str += "\n"
	return ptv_str + simplex_str + dof_str 

	 

def create_function_string_3D(funcname, dof_string, elmat_string):
  nsd = 3
  geometry_string = geometry_string_3D()
  s = """

void %s (map<pair<int,int>,double>& matrix,
         DofT<simplex_i,simplex_i_is_less>& i_dof,
         int element, double pp0[%d], double pp1[%d], double pp2[%d], double pp3[%d]){

   //variables
%s
%s
%s
}
"""% (funcname, nsd,nsd,nsd,nsd,geometry_string, dof_string,elmat_string)
  return s

def create_function_string_3D_2dofs(funcname, dof_string, elmat_string):
  nsd = 3
  geometry_string = geometry_string_3D()
  s = """

void %s (map<pair<int,int>,double>& matrix,
         DofT<simplex_i,simplex_i_is_less>& i_dof,
         DofT<ptv,ptv_is_less>& j_dof,
         int element, double pp0[%d], double pp1[%d], double pp2[%d], double pp3[%d]){

   //variables
%s
%s
%s
}
"""% (funcname, nsd,nsd,nsd,nsd,geometry_string, dof_string,elmat_string)
  return s



