
#include <math.h>
#include <utility>
#include <map>
#include <ptv.h>
#include <simplex.h>
#include "DofT.h"
#include <ScalarFunction.h>
#include <VectorFunction.h>

using namespace std;

namespace pycc {



/* ------------- order 1 ---------------*/



void matrix_factory_mass_sigma_3D_order1 (map<pair<int,int>,double>& matrix,
         DofT<simplex_i,simplex_i_is_less>& i_dof,
         int element, double pp0[3], double pp1[3], double pp2[3], double pp3[3]){

   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; double z0 = pp0[2];
  double x1 = pp1[0]; double y1 = pp1[1]; double z1 = pp1[2];
  double x2 = pp2[0]; double y2 = pp2[1]; double z2 = pp2[2];
  double x3 = pp3[0]; double y3 = pp3[1]; double z3 = pp3[2];

  double G00 = x1 - x0;
  double G10 = y1 - y0;
  double G20 = z1 - z0;

  double G01 = x2 - x0;
  double G11 = y2 - y0;
  double G21 = z2 - z0;

  double G02 = x3 - x0;
  double G12 = y3 - y0;
  double G22 = z3 - z0;

  double D =  G00*(G11*G22-G21*G12)
            - G01*(G10*G22-G20*G12)
            + G02*(G10*G21-G20*G11);




  double dptv0[3];
  dptv0[0] = G00+x0;
  dptv0[1] = y0+G10;
  dptv0[2] = z0+G20;
  ptv ptv0(3,dptv0);

  double dptv1[3];
  dptv1[0] = x0+G02;
  dptv1[1] = G12+y0;
  dptv1[2] = z0+G22;
  ptv ptv1(3,dptv1);

  double dptv2[3];
  dptv2[0] = x0+G01;
  dptv2[1] = y0+G11;
  dptv2[2] = z0+G21;
  ptv ptv2(3,dptv2);

  double dptv3[3];
  dptv3[0] = x0;
  dptv3[1] = y0;
  dptv3[2] = z0;
  ptv ptv3(3,dptv3);

  simplex s0(ptv0, ptv1, ptv2);
  simplex s1(ptv1, ptv2, ptv3);
  simplex s2(ptv3, ptv0, ptv1);
  simplex s3(ptv2, ptv3, ptv0);

  int ii_dof[36];  simplex_i dof0(s0,0,0);
  ii_dof[0] = i_dof.insert_dof(element, 0, dof0);
  simplex_i dof1(s0,1,0);
  ii_dof[1] = i_dof.insert_dof(element, 1, dof1);
  simplex_i dof2(s0,2,0);
  ii_dof[2] = i_dof.insert_dof(element, 2, dof2);
  simplex_i dof3(s1,0,0);
  ii_dof[3] = i_dof.insert_dof(element, 3, dof3);
  simplex_i dof4(s1,1,0);
  ii_dof[4] = i_dof.insert_dof(element, 4, dof4);
  simplex_i dof5(s1,2,0);
  ii_dof[5] = i_dof.insert_dof(element, 5, dof5);
  simplex_i dof6(s2,0,0);
  ii_dof[6] = i_dof.insert_dof(element, 6, dof6);
  simplex_i dof7(s2,1,0);
  ii_dof[7] = i_dof.insert_dof(element, 7, dof7);
  simplex_i dof8(s2,2,0);
  ii_dof[8] = i_dof.insert_dof(element, 8, dof8);
  simplex_i dof9(s3,0,0);
  ii_dof[9] = i_dof.insert_dof(element, 9, dof9);
  simplex_i dof10(s3,1,0);
  ii_dof[10] = i_dof.insert_dof(element, 10, dof10);
  simplex_i dof11(s3,2,0);
  ii_dof[11] = i_dof.insert_dof(element, 11, dof11);
  simplex_i dof12(s0,0,1);
  ii_dof[12] = i_dof.insert_dof(element, 12, dof12);
  simplex_i dof13(s0,1,1);
  ii_dof[13] = i_dof.insert_dof(element, 13, dof13);
  simplex_i dof14(s0,2,1);
  ii_dof[14] = i_dof.insert_dof(element, 14, dof14);
  simplex_i dof15(s1,0,1);
  ii_dof[15] = i_dof.insert_dof(element, 15, dof15);
  simplex_i dof16(s1,1,1);
  ii_dof[16] = i_dof.insert_dof(element, 16, dof16);
  simplex_i dof17(s1,2,1);
  ii_dof[17] = i_dof.insert_dof(element, 17, dof17);
  simplex_i dof18(s2,0,1);
  ii_dof[18] = i_dof.insert_dof(element, 18, dof18);
  simplex_i dof19(s2,1,1);
  ii_dof[19] = i_dof.insert_dof(element, 19, dof19);
  simplex_i dof20(s2,2,1);
  ii_dof[20] = i_dof.insert_dof(element, 20, dof20);
  simplex_i dof21(s3,0,1);
  ii_dof[21] = i_dof.insert_dof(element, 21, dof21);
  simplex_i dof22(s3,1,1);
  ii_dof[22] = i_dof.insert_dof(element, 22, dof22);
  simplex_i dof23(s3,2,1);
  ii_dof[23] = i_dof.insert_dof(element, 23, dof23);
  simplex_i dof24(s0,0,2);
  ii_dof[24] = i_dof.insert_dof(element, 24, dof24);
  simplex_i dof25(s0,1,2);
  ii_dof[25] = i_dof.insert_dof(element, 25, dof25);
  simplex_i dof26(s0,2,2);
  ii_dof[26] = i_dof.insert_dof(element, 26, dof26);
  simplex_i dof27(s1,0,2);
  ii_dof[27] = i_dof.insert_dof(element, 27, dof27);
  simplex_i dof28(s1,1,2);
  ii_dof[28] = i_dof.insert_dof(element, 28, dof28);
  simplex_i dof29(s1,2,2);
  ii_dof[29] = i_dof.insert_dof(element, 29, dof29);
  simplex_i dof30(s2,0,2);
  ii_dof[30] = i_dof.insert_dof(element, 30, dof30);
  simplex_i dof31(s2,1,2);
  ii_dof[31] = i_dof.insert_dof(element, 31, dof31);
  simplex_i dof32(s2,2,2);
  ii_dof[32] = i_dof.insert_dof(element, 32, dof32);
  simplex_i dof33(s3,0,2);
  ii_dof[33] = i_dof.insert_dof(element, 33, dof33);
  simplex_i dof34(s3,1,2);
  ii_dof[34] = i_dof.insert_dof(element, 34, dof34);
  simplex_i dof35(s3,2,2);
  ii_dof[35] = i_dof.insert_dof(element, 35, dof35);


  double A[36][36];
  A[0][0]=(6.5999999999999996e+00)*D;
  A[0][1]=(-3.0000000000000000e+00)*D;
  A[0][2]=(-3.0000000000000000e+00)*D;
  A[0][3]=(9.0000000000000002e-01)*D;
  A[0][4]=(-6.2999999999999998e+00)*D;
  A[0][5]=(3.2999999999999998e+00)*D;
  A[0][6]=(-3.2999999999999998e+00)*D;
  A[0][7]=(-9.0000000000000002e-01)*D;
  A[0][8]=(6.2999999999999998e+00)*D;
  A[0][9]=(2.1000000000000001e+00)*D;
  A[0][10]=(2.1000000000000001e+00)*D;
  A[0][11]=(-2.9999999999999999e-01)*D;
  A[0][12]=(0.0)*D;
  A[0][13]=(0.0)*D;
  A[0][14]=(0.0)*D;
  A[0][15]=(0.0)*D;
  A[0][16]=(0.0)*D;
  A[0][17]=(0.0)*D;
  A[0][18]=(0.0)*D;
  A[0][19]=(0.0)*D;
  A[0][20]=(0.0)*D;
  A[0][21]=(0.0)*D;
  A[0][22]=(0.0)*D;
  A[0][23]=(0.0)*D;
  A[0][24]=(0.0)*D;
  A[0][25]=(0.0)*D;
  A[0][26]=(0.0)*D;
  A[0][27]=(0.0)*D;
  A[0][28]=(0.0)*D;
  A[0][29]=(0.0)*D;
  A[0][30]=(0.0)*D;
  A[0][31]=(0.0)*D;
  A[0][32]=(0.0)*D;
  A[0][33]=(0.0)*D;
  A[0][34]=(0.0)*D;
  A[0][35]=(0.0)*D;
  A[1][0]=(-3.0000000000000000e+00)*D;
  A[1][1]=(6.5999999999999996e+00)*D;
  A[1][2]=(-3.0000000000000000e+00)*D;
  A[1][3]=(9.0000000000000002e-01)*D;
  A[1][4]=(3.2999999999999998e+00)*D;
  A[1][5]=(-6.2999999999999998e+00)*D;
  A[1][6]=(-2.1000000000000001e+00)*D;
  A[1][7]=(2.9999999999999999e-01)*D;
  A[1][8]=(-2.1000000000000001e+00)*D;
  A[1][9]=(-6.2999999999999998e+00)*D;
  A[1][10]=(3.2999999999999998e+00)*D;
  A[1][11]=(9.0000000000000002e-01)*D;
  A[1][12]=(0.0)*D;
  A[1][13]=(0.0)*D;
  A[1][14]=(0.0)*D;
  A[1][15]=(0.0)*D;
  A[1][16]=(0.0)*D;
  A[1][17]=(0.0)*D;
  A[1][18]=(0.0)*D;
  A[1][19]=(0.0)*D;
  A[1][20]=(0.0)*D;
  A[1][21]=(0.0)*D;
  A[1][22]=(0.0)*D;
  A[1][23]=(0.0)*D;
  A[1][24]=(0.0)*D;
  A[1][25]=(0.0)*D;
  A[1][26]=(0.0)*D;
  A[1][27]=(0.0)*D;
  A[1][28]=(0.0)*D;
  A[1][29]=(0.0)*D;
  A[1][30]=(0.0)*D;
  A[1][31]=(0.0)*D;
  A[1][32]=(0.0)*D;
  A[1][33]=(0.0)*D;
  A[1][34]=(0.0)*D;
  A[1][35]=(0.0)*D;
  A[2][0]=(-3.0000000000000000e+00)*D;
  A[2][1]=(-3.0000000000000000e+00)*D;
  A[2][2]=(6.5999999999999996e+00)*D;
  A[2][3]=(-2.9999999999999999e-01)*D;
  A[2][4]=(2.1000000000000001e+00)*D;
  A[2][5]=(2.1000000000000001e+00)*D;
  A[2][6]=(6.2999999999999998e+00)*D;
  A[2][7]=(-9.0000000000000002e-01)*D;
  A[2][8]=(-3.2999999999999998e+00)*D;
  A[2][9]=(3.2999999999999998e+00)*D;
  A[2][10]=(-6.2999999999999998e+00)*D;
  A[2][11]=(9.0000000000000002e-01)*D;
  A[2][12]=(0.0)*D;
  A[2][13]=(0.0)*D;
  A[2][14]=(0.0)*D;
  A[2][15]=(0.0)*D;
  A[2][16]=(0.0)*D;
  A[2][17]=(0.0)*D;
  A[2][18]=(0.0)*D;
  A[2][19]=(0.0)*D;
  A[2][20]=(0.0)*D;
  A[2][21]=(0.0)*D;
  A[2][22]=(0.0)*D;
  A[2][23]=(0.0)*D;
  A[2][24]=(0.0)*D;
  A[2][25]=(0.0)*D;
  A[2][26]=(0.0)*D;
  A[2][27]=(0.0)*D;
  A[2][28]=(0.0)*D;
  A[2][29]=(0.0)*D;
  A[2][30]=(0.0)*D;
  A[2][31]=(0.0)*D;
  A[2][32]=(0.0)*D;
  A[2][33]=(0.0)*D;
  A[2][34]=(0.0)*D;
  A[2][35]=(0.0)*D;
  A[3][0]=(9.0000000000000002e-01)*D;
  A[3][1]=(9.0000000000000002e-01)*D;
  A[3][2]=(-2.9999999999999999e-01)*D;
  A[3][3]=(4.7999999999999998e+00)*D;
  A[3][4]=(-2.3999999999999999e+00)*D;
  A[3][5]=(-2.3999999999999999e+00)*D;
  A[3][6]=(0.0)*D;
  A[3][7]=(-1.2000000000000000e+00)*D;
  A[3][8]=(1.2000000000000000e+00)*D;
  A[3][9]=(-1.2000000000000000e+00)*D;
  A[3][10]=(0.0)*D;
  A[3][11]=(1.2000000000000000e+00)*D;
  A[3][12]=(0.0)*D;
  A[3][13]=(0.0)*D;
  A[3][14]=(0.0)*D;
  A[3][15]=(0.0)*D;
  A[3][16]=(0.0)*D;
  A[3][17]=(0.0)*D;
  A[3][18]=(0.0)*D;
  A[3][19]=(0.0)*D;
  A[3][20]=(0.0)*D;
  A[3][21]=(0.0)*D;
  A[3][22]=(0.0)*D;
  A[3][23]=(0.0)*D;
  A[3][24]=(0.0)*D;
  A[3][25]=(0.0)*D;
  A[3][26]=(0.0)*D;
  A[3][27]=(0.0)*D;
  A[3][28]=(0.0)*D;
  A[3][29]=(0.0)*D;
  A[3][30]=(0.0)*D;
  A[3][31]=(0.0)*D;
  A[3][32]=(0.0)*D;
  A[3][33]=(0.0)*D;
  A[3][34]=(0.0)*D;
  A[3][35]=(0.0)*D;
  A[4][0]=(-6.2999999999999998e+00)*D;
  A[4][1]=(3.2999999999999998e+00)*D;
  A[4][2]=(2.1000000000000001e+00)*D;
  A[4][3]=(-2.3999999999999999e+00)*D;
  A[4][4]=(9.5999999999999996e+00)*D;
  A[4][5]=(-4.7999999999999998e+00)*D;
  A[4][6]=(2.3999999999999999e+00)*D;
  A[4][7]=(1.2000000000000000e+00)*D;
  A[4][8]=(-6.0000000000000000e+00)*D;
  A[4][9]=(-2.3999999999999999e+00)*D;
  A[4][10]=(-1.2000000000000000e+00)*D;
  A[4][11]=(0.0)*D;
  A[4][12]=(0.0)*D;
  A[4][13]=(0.0)*D;
  A[4][14]=(0.0)*D;
  A[4][15]=(0.0)*D;
  A[4][16]=(0.0)*D;
  A[4][17]=(0.0)*D;
  A[4][18]=(0.0)*D;
  A[4][19]=(0.0)*D;
  A[4][20]=(0.0)*D;
  A[4][21]=(0.0)*D;
  A[4][22]=(0.0)*D;
  A[4][23]=(0.0)*D;
  A[4][24]=(0.0)*D;
  A[4][25]=(0.0)*D;
  A[4][26]=(0.0)*D;
  A[4][27]=(0.0)*D;
  A[4][28]=(0.0)*D;
  A[4][29]=(0.0)*D;
  A[4][30]=(0.0)*D;
  A[4][31]=(0.0)*D;
  A[4][32]=(0.0)*D;
  A[4][33]=(0.0)*D;
  A[4][34]=(0.0)*D;
  A[4][35]=(0.0)*D;
  A[5][0]=(3.2999999999999998e+00)*D;
  A[5][1]=(-6.2999999999999998e+00)*D;
  A[5][2]=(2.1000000000000001e+00)*D;
  A[5][3]=(-2.3999999999999999e+00)*D;
  A[5][4]=(-4.7999999999999998e+00)*D;
  A[5][5]=(9.5999999999999996e+00)*D;
  A[5][6]=(1.2000000000000000e+00)*D;
  A[5][7]=(0.0)*D;
  A[5][8]=(2.3999999999999999e+00)*D;
  A[5][9]=(6.0000000000000000e+00)*D;
  A[5][10]=(-2.3999999999999999e+00)*D;
  A[5][11]=(-1.2000000000000000e+00)*D;
  A[5][12]=(0.0)*D;
  A[5][13]=(0.0)*D;
  A[5][14]=(0.0)*D;
  A[5][15]=(0.0)*D;
  A[5][16]=(0.0)*D;
  A[5][17]=(0.0)*D;
  A[5][18]=(0.0)*D;
  A[5][19]=(0.0)*D;
  A[5][20]=(0.0)*D;
  A[5][21]=(0.0)*D;
  A[5][22]=(0.0)*D;
  A[5][23]=(0.0)*D;
  A[5][24]=(0.0)*D;
  A[5][25]=(0.0)*D;
  A[5][26]=(0.0)*D;
  A[5][27]=(0.0)*D;
  A[5][28]=(0.0)*D;
  A[5][29]=(0.0)*D;
  A[5][30]=(0.0)*D;
  A[5][31]=(0.0)*D;
  A[5][32]=(0.0)*D;
  A[5][33]=(0.0)*D;
  A[5][34]=(0.0)*D;
  A[5][35]=(0.0)*D;
  A[6][0]=(-3.2999999999999998e+00)*D;
  A[6][1]=(-2.1000000000000001e+00)*D;
  A[6][2]=(6.2999999999999998e+00)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(2.3999999999999999e+00)*D;
  A[6][5]=(1.2000000000000000e+00)*D;
  A[6][6]=(9.5999999999999996e+00)*D;
  A[6][7]=(-2.3999999999999999e+00)*D;
  A[6][8]=(-4.7999999999999998e+00)*D;
  A[6][9]=(2.3999999999999999e+00)*D;
  A[6][10]=(-6.0000000000000000e+00)*D;
  A[6][11]=(1.2000000000000000e+00)*D;
  A[6][12]=(0.0)*D;
  A[6][13]=(0.0)*D;
  A[6][14]=(0.0)*D;
  A[6][15]=(0.0)*D;
  A[6][16]=(0.0)*D;
  A[6][17]=(0.0)*D;
  A[6][18]=(0.0)*D;
  A[6][19]=(0.0)*D;
  A[6][20]=(0.0)*D;
  A[6][21]=(0.0)*D;
  A[6][22]=(0.0)*D;
  A[6][23]=(0.0)*D;
  A[6][24]=(0.0)*D;
  A[6][25]=(0.0)*D;
  A[6][26]=(0.0)*D;
  A[6][27]=(0.0)*D;
  A[6][28]=(0.0)*D;
  A[6][29]=(0.0)*D;
  A[6][30]=(0.0)*D;
  A[6][31]=(0.0)*D;
  A[6][32]=(0.0)*D;
  A[6][33]=(0.0)*D;
  A[6][34]=(0.0)*D;
  A[6][35]=(0.0)*D;
  A[7][0]=(-9.0000000000000002e-01)*D;
  A[7][1]=(2.9999999999999999e-01)*D;
  A[7][2]=(-9.0000000000000002e-01)*D;
  A[7][3]=(-1.2000000000000000e+00)*D;
  A[7][4]=(1.2000000000000000e+00)*D;
  A[7][5]=(0.0)*D;
  A[7][6]=(-2.3999999999999999e+00)*D;
  A[7][7]=(4.7999999999999998e+00)*D;
  A[7][8]=(-2.3999999999999999e+00)*D;
  A[7][9]=(0.0)*D;
  A[7][10]=(1.2000000000000000e+00)*D;
  A[7][11]=(-1.2000000000000000e+00)*D;
  A[7][12]=(0.0)*D;
  A[7][13]=(0.0)*D;
  A[7][14]=(0.0)*D;
  A[7][15]=(0.0)*D;
  A[7][16]=(0.0)*D;
  A[7][17]=(0.0)*D;
  A[7][18]=(0.0)*D;
  A[7][19]=(0.0)*D;
  A[7][20]=(0.0)*D;
  A[7][21]=(0.0)*D;
  A[7][22]=(0.0)*D;
  A[7][23]=(0.0)*D;
  A[7][24]=(0.0)*D;
  A[7][25]=(0.0)*D;
  A[7][26]=(0.0)*D;
  A[7][27]=(0.0)*D;
  A[7][28]=(0.0)*D;
  A[7][29]=(0.0)*D;
  A[7][30]=(0.0)*D;
  A[7][31]=(0.0)*D;
  A[7][32]=(0.0)*D;
  A[7][33]=(0.0)*D;
  A[7][34]=(0.0)*D;
  A[7][35]=(0.0)*D;
  A[8][0]=(6.2999999999999998e+00)*D;
  A[8][1]=(-2.1000000000000001e+00)*D;
  A[8][2]=(-3.2999999999999998e+00)*D;
  A[8][3]=(1.2000000000000000e+00)*D;
  A[8][4]=(-6.0000000000000000e+00)*D;
  A[8][5]=(2.3999999999999999e+00)*D;
  A[8][6]=(-4.7999999999999998e+00)*D;
  A[8][7]=(-2.3999999999999999e+00)*D;
  A[8][8]=(9.5999999999999996e+00)*D;
  A[8][9]=(1.2000000000000000e+00)*D;
  A[8][10]=(2.3999999999999999e+00)*D;
  A[8][11]=(0.0)*D;
  A[8][12]=(0.0)*D;
  A[8][13]=(0.0)*D;
  A[8][14]=(0.0)*D;
  A[8][15]=(0.0)*D;
  A[8][16]=(0.0)*D;
  A[8][17]=(0.0)*D;
  A[8][18]=(0.0)*D;
  A[8][19]=(0.0)*D;
  A[8][20]=(0.0)*D;
  A[8][21]=(0.0)*D;
  A[8][22]=(0.0)*D;
  A[8][23]=(0.0)*D;
  A[8][24]=(0.0)*D;
  A[8][25]=(0.0)*D;
  A[8][26]=(0.0)*D;
  A[8][27]=(0.0)*D;
  A[8][28]=(0.0)*D;
  A[8][29]=(0.0)*D;
  A[8][30]=(0.0)*D;
  A[8][31]=(0.0)*D;
  A[8][32]=(0.0)*D;
  A[8][33]=(0.0)*D;
  A[8][34]=(0.0)*D;
  A[8][35]=(0.0)*D;
  A[9][0]=(2.1000000000000001e+00)*D;
  A[9][1]=(-6.2999999999999998e+00)*D;
  A[9][2]=(3.2999999999999998e+00)*D;
  A[9][3]=(-1.2000000000000000e+00)*D;
  A[9][4]=(-2.3999999999999999e+00)*D;
  A[9][5]=(6.0000000000000000e+00)*D;
  A[9][6]=(2.3999999999999999e+00)*D;
  A[9][7]=(0.0)*D;
  A[9][8]=(1.2000000000000000e+00)*D;
  A[9][9]=(9.5999999999999996e+00)*D;
  A[9][10]=(-4.7999999999999998e+00)*D;
  A[9][11]=(-2.3999999999999999e+00)*D;
  A[9][12]=(0.0)*D;
  A[9][13]=(0.0)*D;
  A[9][14]=(0.0)*D;
  A[9][15]=(0.0)*D;
  A[9][16]=(0.0)*D;
  A[9][17]=(0.0)*D;
  A[9][18]=(0.0)*D;
  A[9][19]=(0.0)*D;
  A[9][20]=(0.0)*D;
  A[9][21]=(0.0)*D;
  A[9][22]=(0.0)*D;
  A[9][23]=(0.0)*D;
  A[9][24]=(0.0)*D;
  A[9][25]=(0.0)*D;
  A[9][26]=(0.0)*D;
  A[9][27]=(0.0)*D;
  A[9][28]=(0.0)*D;
  A[9][29]=(0.0)*D;
  A[9][30]=(0.0)*D;
  A[9][31]=(0.0)*D;
  A[9][32]=(0.0)*D;
  A[9][33]=(0.0)*D;
  A[9][34]=(0.0)*D;
  A[9][35]=(0.0)*D;
  A[10][0]=(2.1000000000000001e+00)*D;
  A[10][1]=(3.2999999999999998e+00)*D;
  A[10][2]=(-6.2999999999999998e+00)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=(-1.2000000000000000e+00)*D;
  A[10][5]=(-2.3999999999999999e+00)*D;
  A[10][6]=(-6.0000000000000000e+00)*D;
  A[10][7]=(1.2000000000000000e+00)*D;
  A[10][8]=(2.3999999999999999e+00)*D;
  A[10][9]=(-4.7999999999999998e+00)*D;
  A[10][10]=(9.5999999999999996e+00)*D;
  A[10][11]=(-2.3999999999999999e+00)*D;
  A[10][12]=(0.0)*D;
  A[10][13]=(0.0)*D;
  A[10][14]=(0.0)*D;
  A[10][15]=(0.0)*D;
  A[10][16]=(0.0)*D;
  A[10][17]=(0.0)*D;
  A[10][18]=(0.0)*D;
  A[10][19]=(0.0)*D;
  A[10][20]=(0.0)*D;
  A[10][21]=(0.0)*D;
  A[10][22]=(0.0)*D;
  A[10][23]=(0.0)*D;
  A[10][24]=(0.0)*D;
  A[10][25]=(0.0)*D;
  A[10][26]=(0.0)*D;
  A[10][27]=(0.0)*D;
  A[10][28]=(0.0)*D;
  A[10][29]=(0.0)*D;
  A[10][30]=(0.0)*D;
  A[10][31]=(0.0)*D;
  A[10][32]=(0.0)*D;
  A[10][33]=(0.0)*D;
  A[10][34]=(0.0)*D;
  A[10][35]=(0.0)*D;
  A[11][0]=(-2.9999999999999999e-01)*D;
  A[11][1]=(9.0000000000000002e-01)*D;
  A[11][2]=(9.0000000000000002e-01)*D;
  A[11][3]=(1.2000000000000000e+00)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=(-1.2000000000000000e+00)*D;
  A[11][6]=(1.2000000000000000e+00)*D;
  A[11][7]=(-1.2000000000000000e+00)*D;
  A[11][8]=(0.0)*D;
  A[11][9]=(-2.3999999999999999e+00)*D;
  A[11][10]=(-2.3999999999999999e+00)*D;
  A[11][11]=(4.7999999999999998e+00)*D;
  A[11][12]=(0.0)*D;
  A[11][13]=(0.0)*D;
  A[11][14]=(0.0)*D;
  A[11][15]=(0.0)*D;
  A[11][16]=(0.0)*D;
  A[11][17]=(0.0)*D;
  A[11][18]=(0.0)*D;
  A[11][19]=(0.0)*D;
  A[11][20]=(0.0)*D;
  A[11][21]=(0.0)*D;
  A[11][22]=(0.0)*D;
  A[11][23]=(0.0)*D;
  A[11][24]=(0.0)*D;
  A[11][25]=(0.0)*D;
  A[11][26]=(0.0)*D;
  A[11][27]=(0.0)*D;
  A[11][28]=(0.0)*D;
  A[11][29]=(0.0)*D;
  A[11][30]=(0.0)*D;
  A[11][31]=(0.0)*D;
  A[11][32]=(0.0)*D;
  A[11][33]=(0.0)*D;
  A[11][34]=(0.0)*D;
  A[11][35]=(0.0)*D;
  A[12][0]=(0.0)*D;
  A[12][1]=(0.0)*D;
  A[12][2]=(0.0)*D;
  A[12][3]=(0.0)*D;
  A[12][4]=(0.0)*D;
  A[12][5]=(0.0)*D;
  A[12][6]=(0.0)*D;
  A[12][7]=(0.0)*D;
  A[12][8]=(0.0)*D;
  A[12][9]=(0.0)*D;
  A[12][10]=(0.0)*D;
  A[12][11]=(0.0)*D;
  A[12][12]=(6.5999999999999996e+00)*D;
  A[12][13]=(-3.0000000000000000e+00)*D;
  A[12][14]=(-3.0000000000000000e+00)*D;
  A[12][15]=(9.0000000000000002e-01)*D;
  A[12][16]=(-6.2999999999999998e+00)*D;
  A[12][17]=(3.2999999999999998e+00)*D;
  A[12][18]=(-3.2999999999999998e+00)*D;
  A[12][19]=(-9.0000000000000002e-01)*D;
  A[12][20]=(6.2999999999999998e+00)*D;
  A[12][21]=(2.1000000000000001e+00)*D;
  A[12][22]=(2.1000000000000001e+00)*D;
  A[12][23]=(-2.9999999999999999e-01)*D;
  A[12][24]=(0.0)*D;
  A[12][25]=(0.0)*D;
  A[12][26]=(0.0)*D;
  A[12][27]=(0.0)*D;
  A[12][28]=(0.0)*D;
  A[12][29]=(0.0)*D;
  A[12][30]=(0.0)*D;
  A[12][31]=(0.0)*D;
  A[12][32]=(0.0)*D;
  A[12][33]=(0.0)*D;
  A[12][34]=(0.0)*D;
  A[12][35]=(0.0)*D;
  A[13][0]=(0.0)*D;
  A[13][1]=(0.0)*D;
  A[13][2]=(0.0)*D;
  A[13][3]=(0.0)*D;
  A[13][4]=(0.0)*D;
  A[13][5]=(0.0)*D;
  A[13][6]=(0.0)*D;
  A[13][7]=(0.0)*D;
  A[13][8]=(0.0)*D;
  A[13][9]=(0.0)*D;
  A[13][10]=(0.0)*D;
  A[13][11]=(0.0)*D;
  A[13][12]=(-3.0000000000000000e+00)*D;
  A[13][13]=(6.5999999999999996e+00)*D;
  A[13][14]=(-3.0000000000000000e+00)*D;
  A[13][15]=(9.0000000000000002e-01)*D;
  A[13][16]=(3.2999999999999998e+00)*D;
  A[13][17]=(-6.2999999999999998e+00)*D;
  A[13][18]=(-2.1000000000000001e+00)*D;
  A[13][19]=(2.9999999999999999e-01)*D;
  A[13][20]=(-2.1000000000000001e+00)*D;
  A[13][21]=(-6.2999999999999998e+00)*D;
  A[13][22]=(3.2999999999999998e+00)*D;
  A[13][23]=(9.0000000000000002e-01)*D;
  A[13][24]=(0.0)*D;
  A[13][25]=(0.0)*D;
  A[13][26]=(0.0)*D;
  A[13][27]=(0.0)*D;
  A[13][28]=(0.0)*D;
  A[13][29]=(0.0)*D;
  A[13][30]=(0.0)*D;
  A[13][31]=(0.0)*D;
  A[13][32]=(0.0)*D;
  A[13][33]=(0.0)*D;
  A[13][34]=(0.0)*D;
  A[13][35]=(0.0)*D;
  A[14][0]=(0.0)*D;
  A[14][1]=(0.0)*D;
  A[14][2]=(0.0)*D;
  A[14][3]=(0.0)*D;
  A[14][4]=(0.0)*D;
  A[14][5]=(0.0)*D;
  A[14][6]=(0.0)*D;
  A[14][7]=(0.0)*D;
  A[14][8]=(0.0)*D;
  A[14][9]=(0.0)*D;
  A[14][10]=(0.0)*D;
  A[14][11]=(0.0)*D;
  A[14][12]=(-3.0000000000000000e+00)*D;
  A[14][13]=(-3.0000000000000000e+00)*D;
  A[14][14]=(6.5999999999999996e+00)*D;
  A[14][15]=(-2.9999999999999999e-01)*D;
  A[14][16]=(2.1000000000000001e+00)*D;
  A[14][17]=(2.1000000000000001e+00)*D;
  A[14][18]=(6.2999999999999998e+00)*D;
  A[14][19]=(-9.0000000000000002e-01)*D;
  A[14][20]=(-3.2999999999999998e+00)*D;
  A[14][21]=(3.2999999999999998e+00)*D;
  A[14][22]=(-6.2999999999999998e+00)*D;
  A[14][23]=(9.0000000000000002e-01)*D;
  A[14][24]=(0.0)*D;
  A[14][25]=(0.0)*D;
  A[14][26]=(0.0)*D;
  A[14][27]=(0.0)*D;
  A[14][28]=(0.0)*D;
  A[14][29]=(0.0)*D;
  A[14][30]=(0.0)*D;
  A[14][31]=(0.0)*D;
  A[14][32]=(0.0)*D;
  A[14][33]=(0.0)*D;
  A[14][34]=(0.0)*D;
  A[14][35]=(0.0)*D;
  A[15][0]=(0.0)*D;
  A[15][1]=(0.0)*D;
  A[15][2]=(0.0)*D;
  A[15][3]=(0.0)*D;
  A[15][4]=(0.0)*D;
  A[15][5]=(0.0)*D;
  A[15][6]=(0.0)*D;
  A[15][7]=(0.0)*D;
  A[15][8]=(0.0)*D;
  A[15][9]=(0.0)*D;
  A[15][10]=(0.0)*D;
  A[15][11]=(0.0)*D;
  A[15][12]=(9.0000000000000002e-01)*D;
  A[15][13]=(9.0000000000000002e-01)*D;
  A[15][14]=(-2.9999999999999999e-01)*D;
  A[15][15]=(4.7999999999999998e+00)*D;
  A[15][16]=(-2.3999999999999999e+00)*D;
  A[15][17]=(-2.3999999999999999e+00)*D;
  A[15][18]=(0.0)*D;
  A[15][19]=(-1.2000000000000000e+00)*D;
  A[15][20]=(1.2000000000000000e+00)*D;
  A[15][21]=(-1.2000000000000000e+00)*D;
  A[15][22]=(0.0)*D;
  A[15][23]=(1.2000000000000000e+00)*D;
  A[15][24]=(0.0)*D;
  A[15][25]=(0.0)*D;
  A[15][26]=(0.0)*D;
  A[15][27]=(0.0)*D;
  A[15][28]=(0.0)*D;
  A[15][29]=(0.0)*D;
  A[15][30]=(0.0)*D;
  A[15][31]=(0.0)*D;
  A[15][32]=(0.0)*D;
  A[15][33]=(0.0)*D;
  A[15][34]=(0.0)*D;
  A[15][35]=(0.0)*D;
  A[16][0]=(0.0)*D;
  A[16][1]=(0.0)*D;
  A[16][2]=(0.0)*D;
  A[16][3]=(0.0)*D;
  A[16][4]=(0.0)*D;
  A[16][5]=(0.0)*D;
  A[16][6]=(0.0)*D;
  A[16][7]=(0.0)*D;
  A[16][8]=(0.0)*D;
  A[16][9]=(0.0)*D;
  A[16][10]=(0.0)*D;
  A[16][11]=(0.0)*D;
  A[16][12]=(-6.2999999999999998e+00)*D;
  A[16][13]=(3.2999999999999998e+00)*D;
  A[16][14]=(2.1000000000000001e+00)*D;
  A[16][15]=(-2.3999999999999999e+00)*D;
  A[16][16]=(9.5999999999999996e+00)*D;
  A[16][17]=(-4.7999999999999998e+00)*D;
  A[16][18]=(2.3999999999999999e+00)*D;
  A[16][19]=(1.2000000000000000e+00)*D;
  A[16][20]=(-6.0000000000000000e+00)*D;
  A[16][21]=(-2.3999999999999999e+00)*D;
  A[16][22]=(-1.2000000000000000e+00)*D;
  A[16][23]=(0.0)*D;
  A[16][24]=(0.0)*D;
  A[16][25]=(0.0)*D;
  A[16][26]=(0.0)*D;
  A[16][27]=(0.0)*D;
  A[16][28]=(0.0)*D;
  A[16][29]=(0.0)*D;
  A[16][30]=(0.0)*D;
  A[16][31]=(0.0)*D;
  A[16][32]=(0.0)*D;
  A[16][33]=(0.0)*D;
  A[16][34]=(0.0)*D;
  A[16][35]=(0.0)*D;
  A[17][0]=(0.0)*D;
  A[17][1]=(0.0)*D;
  A[17][2]=(0.0)*D;
  A[17][3]=(0.0)*D;
  A[17][4]=(0.0)*D;
  A[17][5]=(0.0)*D;
  A[17][6]=(0.0)*D;
  A[17][7]=(0.0)*D;
  A[17][8]=(0.0)*D;
  A[17][9]=(0.0)*D;
  A[17][10]=(0.0)*D;
  A[17][11]=(0.0)*D;
  A[17][12]=(3.2999999999999998e+00)*D;
  A[17][13]=(-6.2999999999999998e+00)*D;
  A[17][14]=(2.1000000000000001e+00)*D;
  A[17][15]=(-2.3999999999999999e+00)*D;
  A[17][16]=(-4.7999999999999998e+00)*D;
  A[17][17]=(9.5999999999999996e+00)*D;
  A[17][18]=(1.2000000000000000e+00)*D;
  A[17][19]=(0.0)*D;
  A[17][20]=(2.3999999999999999e+00)*D;
  A[17][21]=(6.0000000000000000e+00)*D;
  A[17][22]=(-2.3999999999999999e+00)*D;
  A[17][23]=(-1.2000000000000000e+00)*D;
  A[17][24]=(0.0)*D;
  A[17][25]=(0.0)*D;
  A[17][26]=(0.0)*D;
  A[17][27]=(0.0)*D;
  A[17][28]=(0.0)*D;
  A[17][29]=(0.0)*D;
  A[17][30]=(0.0)*D;
  A[17][31]=(0.0)*D;
  A[17][32]=(0.0)*D;
  A[17][33]=(0.0)*D;
  A[17][34]=(0.0)*D;
  A[17][35]=(0.0)*D;
  A[18][0]=(0.0)*D;
  A[18][1]=(0.0)*D;
  A[18][2]=(0.0)*D;
  A[18][3]=(0.0)*D;
  A[18][4]=(0.0)*D;
  A[18][5]=(0.0)*D;
  A[18][6]=(0.0)*D;
  A[18][7]=(0.0)*D;
  A[18][8]=(0.0)*D;
  A[18][9]=(0.0)*D;
  A[18][10]=(0.0)*D;
  A[18][11]=(0.0)*D;
  A[18][12]=(-3.2999999999999998e+00)*D;
  A[18][13]=(-2.1000000000000001e+00)*D;
  A[18][14]=(6.2999999999999998e+00)*D;
  A[18][15]=(0.0)*D;
  A[18][16]=(2.3999999999999999e+00)*D;
  A[18][17]=(1.2000000000000000e+00)*D;
  A[18][18]=(9.5999999999999996e+00)*D;
  A[18][19]=(-2.3999999999999999e+00)*D;
  A[18][20]=(-4.7999999999999998e+00)*D;
  A[18][21]=(2.3999999999999999e+00)*D;
  A[18][22]=(-6.0000000000000000e+00)*D;
  A[18][23]=(1.2000000000000000e+00)*D;
  A[18][24]=(0.0)*D;
  A[18][25]=(0.0)*D;
  A[18][26]=(0.0)*D;
  A[18][27]=(0.0)*D;
  A[18][28]=(0.0)*D;
  A[18][29]=(0.0)*D;
  A[18][30]=(0.0)*D;
  A[18][31]=(0.0)*D;
  A[18][32]=(0.0)*D;
  A[18][33]=(0.0)*D;
  A[18][34]=(0.0)*D;
  A[18][35]=(0.0)*D;
  A[19][0]=(0.0)*D;
  A[19][1]=(0.0)*D;
  A[19][2]=(0.0)*D;
  A[19][3]=(0.0)*D;
  A[19][4]=(0.0)*D;
  A[19][5]=(0.0)*D;
  A[19][6]=(0.0)*D;
  A[19][7]=(0.0)*D;
  A[19][8]=(0.0)*D;
  A[19][9]=(0.0)*D;
  A[19][10]=(0.0)*D;
  A[19][11]=(0.0)*D;
  A[19][12]=(-9.0000000000000002e-01)*D;
  A[19][13]=(2.9999999999999999e-01)*D;
  A[19][14]=(-9.0000000000000002e-01)*D;
  A[19][15]=(-1.2000000000000000e+00)*D;
  A[19][16]=(1.2000000000000000e+00)*D;
  A[19][17]=(0.0)*D;
  A[19][18]=(-2.3999999999999999e+00)*D;
  A[19][19]=(4.7999999999999998e+00)*D;
  A[19][20]=(-2.3999999999999999e+00)*D;
  A[19][21]=(0.0)*D;
  A[19][22]=(1.2000000000000000e+00)*D;
  A[19][23]=(-1.2000000000000000e+00)*D;
  A[19][24]=(0.0)*D;
  A[19][25]=(0.0)*D;
  A[19][26]=(0.0)*D;
  A[19][27]=(0.0)*D;
  A[19][28]=(0.0)*D;
  A[19][29]=(0.0)*D;
  A[19][30]=(0.0)*D;
  A[19][31]=(0.0)*D;
  A[19][32]=(0.0)*D;
  A[19][33]=(0.0)*D;
  A[19][34]=(0.0)*D;
  A[19][35]=(0.0)*D;
  A[20][0]=(0.0)*D;
  A[20][1]=(0.0)*D;
  A[20][2]=(0.0)*D;
  A[20][3]=(0.0)*D;
  A[20][4]=(0.0)*D;
  A[20][5]=(0.0)*D;
  A[20][6]=(0.0)*D;
  A[20][7]=(0.0)*D;
  A[20][8]=(0.0)*D;
  A[20][9]=(0.0)*D;
  A[20][10]=(0.0)*D;
  A[20][11]=(0.0)*D;
  A[20][12]=(6.2999999999999998e+00)*D;
  A[20][13]=(-2.1000000000000001e+00)*D;
  A[20][14]=(-3.2999999999999998e+00)*D;
  A[20][15]=(1.2000000000000000e+00)*D;
  A[20][16]=(-6.0000000000000000e+00)*D;
  A[20][17]=(2.3999999999999999e+00)*D;
  A[20][18]=(-4.7999999999999998e+00)*D;
  A[20][19]=(-2.3999999999999999e+00)*D;
  A[20][20]=(9.5999999999999996e+00)*D;
  A[20][21]=(1.2000000000000000e+00)*D;
  A[20][22]=(2.3999999999999999e+00)*D;
  A[20][23]=(0.0)*D;
  A[20][24]=(0.0)*D;
  A[20][25]=(0.0)*D;
  A[20][26]=(0.0)*D;
  A[20][27]=(0.0)*D;
  A[20][28]=(0.0)*D;
  A[20][29]=(0.0)*D;
  A[20][30]=(0.0)*D;
  A[20][31]=(0.0)*D;
  A[20][32]=(0.0)*D;
  A[20][33]=(0.0)*D;
  A[20][34]=(0.0)*D;
  A[20][35]=(0.0)*D;
  A[21][0]=(0.0)*D;
  A[21][1]=(0.0)*D;
  A[21][2]=(0.0)*D;
  A[21][3]=(0.0)*D;
  A[21][4]=(0.0)*D;
  A[21][5]=(0.0)*D;
  A[21][6]=(0.0)*D;
  A[21][7]=(0.0)*D;
  A[21][8]=(0.0)*D;
  A[21][9]=(0.0)*D;
  A[21][10]=(0.0)*D;
  A[21][11]=(0.0)*D;
  A[21][12]=(2.1000000000000001e+00)*D;
  A[21][13]=(-6.2999999999999998e+00)*D;
  A[21][14]=(3.2999999999999998e+00)*D;
  A[21][15]=(-1.2000000000000000e+00)*D;
  A[21][16]=(-2.3999999999999999e+00)*D;
  A[21][17]=(6.0000000000000000e+00)*D;
  A[21][18]=(2.3999999999999999e+00)*D;
  A[21][19]=(0.0)*D;
  A[21][20]=(1.2000000000000000e+00)*D;
  A[21][21]=(9.5999999999999996e+00)*D;
  A[21][22]=(-4.7999999999999998e+00)*D;
  A[21][23]=(-2.3999999999999999e+00)*D;
  A[21][24]=(0.0)*D;
  A[21][25]=(0.0)*D;
  A[21][26]=(0.0)*D;
  A[21][27]=(0.0)*D;
  A[21][28]=(0.0)*D;
  A[21][29]=(0.0)*D;
  A[21][30]=(0.0)*D;
  A[21][31]=(0.0)*D;
  A[21][32]=(0.0)*D;
  A[21][33]=(0.0)*D;
  A[21][34]=(0.0)*D;
  A[21][35]=(0.0)*D;
  A[22][0]=(0.0)*D;
  A[22][1]=(0.0)*D;
  A[22][2]=(0.0)*D;
  A[22][3]=(0.0)*D;
  A[22][4]=(0.0)*D;
  A[22][5]=(0.0)*D;
  A[22][6]=(0.0)*D;
  A[22][7]=(0.0)*D;
  A[22][8]=(0.0)*D;
  A[22][9]=(0.0)*D;
  A[22][10]=(0.0)*D;
  A[22][11]=(0.0)*D;
  A[22][12]=(2.1000000000000001e+00)*D;
  A[22][13]=(3.2999999999999998e+00)*D;
  A[22][14]=(-6.2999999999999998e+00)*D;
  A[22][15]=(0.0)*D;
  A[22][16]=(-1.2000000000000000e+00)*D;
  A[22][17]=(-2.3999999999999999e+00)*D;
  A[22][18]=(-6.0000000000000000e+00)*D;
  A[22][19]=(1.2000000000000000e+00)*D;
  A[22][20]=(2.3999999999999999e+00)*D;
  A[22][21]=(-4.7999999999999998e+00)*D;
  A[22][22]=(9.5999999999999996e+00)*D;
  A[22][23]=(-2.3999999999999999e+00)*D;
  A[22][24]=(0.0)*D;
  A[22][25]=(0.0)*D;
  A[22][26]=(0.0)*D;
  A[22][27]=(0.0)*D;
  A[22][28]=(0.0)*D;
  A[22][29]=(0.0)*D;
  A[22][30]=(0.0)*D;
  A[22][31]=(0.0)*D;
  A[22][32]=(0.0)*D;
  A[22][33]=(0.0)*D;
  A[22][34]=(0.0)*D;
  A[22][35]=(0.0)*D;
  A[23][0]=(0.0)*D;
  A[23][1]=(0.0)*D;
  A[23][2]=(0.0)*D;
  A[23][3]=(0.0)*D;
  A[23][4]=(0.0)*D;
  A[23][5]=(0.0)*D;
  A[23][6]=(0.0)*D;
  A[23][7]=(0.0)*D;
  A[23][8]=(0.0)*D;
  A[23][9]=(0.0)*D;
  A[23][10]=(0.0)*D;
  A[23][11]=(0.0)*D;
  A[23][12]=(-2.9999999999999999e-01)*D;
  A[23][13]=(9.0000000000000002e-01)*D;
  A[23][14]=(9.0000000000000002e-01)*D;
  A[23][15]=(1.2000000000000000e+00)*D;
  A[23][16]=(0.0)*D;
  A[23][17]=(-1.2000000000000000e+00)*D;
  A[23][18]=(1.2000000000000000e+00)*D;
  A[23][19]=(-1.2000000000000000e+00)*D;
  A[23][20]=(0.0)*D;
  A[23][21]=(-2.3999999999999999e+00)*D;
  A[23][22]=(-2.3999999999999999e+00)*D;
  A[23][23]=(4.7999999999999998e+00)*D;
  A[23][24]=(0.0)*D;
  A[23][25]=(0.0)*D;
  A[23][26]=(0.0)*D;
  A[23][27]=(0.0)*D;
  A[23][28]=(0.0)*D;
  A[23][29]=(0.0)*D;
  A[23][30]=(0.0)*D;
  A[23][31]=(0.0)*D;
  A[23][32]=(0.0)*D;
  A[23][33]=(0.0)*D;
  A[23][34]=(0.0)*D;
  A[23][35]=(0.0)*D;
  A[24][0]=(0.0)*D;
  A[24][1]=(0.0)*D;
  A[24][2]=(0.0)*D;
  A[24][3]=(0.0)*D;
  A[24][4]=(0.0)*D;
  A[24][5]=(0.0)*D;
  A[24][6]=(0.0)*D;
  A[24][7]=(0.0)*D;
  A[24][8]=(0.0)*D;
  A[24][9]=(0.0)*D;
  A[24][10]=(0.0)*D;
  A[24][11]=(0.0)*D;
  A[24][12]=(0.0)*D;
  A[24][13]=(0.0)*D;
  A[24][14]=(0.0)*D;
  A[24][15]=(0.0)*D;
  A[24][16]=(0.0)*D;
  A[24][17]=(0.0)*D;
  A[24][18]=(0.0)*D;
  A[24][19]=(0.0)*D;
  A[24][20]=(0.0)*D;
  A[24][21]=(0.0)*D;
  A[24][22]=(0.0)*D;
  A[24][23]=(0.0)*D;
  A[24][24]=(6.5999999999999996e+00)*D;
  A[24][25]=(-3.0000000000000000e+00)*D;
  A[24][26]=(-3.0000000000000000e+00)*D;
  A[24][27]=(9.0000000000000002e-01)*D;
  A[24][28]=(-6.2999999999999998e+00)*D;
  A[24][29]=(3.2999999999999998e+00)*D;
  A[24][30]=(-3.2999999999999998e+00)*D;
  A[24][31]=(-9.0000000000000002e-01)*D;
  A[24][32]=(6.2999999999999998e+00)*D;
  A[24][33]=(2.1000000000000001e+00)*D;
  A[24][34]=(2.1000000000000001e+00)*D;
  A[24][35]=(-2.9999999999999999e-01)*D;
  A[25][0]=(0.0)*D;
  A[25][1]=(0.0)*D;
  A[25][2]=(0.0)*D;
  A[25][3]=(0.0)*D;
  A[25][4]=(0.0)*D;
  A[25][5]=(0.0)*D;
  A[25][6]=(0.0)*D;
  A[25][7]=(0.0)*D;
  A[25][8]=(0.0)*D;
  A[25][9]=(0.0)*D;
  A[25][10]=(0.0)*D;
  A[25][11]=(0.0)*D;
  A[25][12]=(0.0)*D;
  A[25][13]=(0.0)*D;
  A[25][14]=(0.0)*D;
  A[25][15]=(0.0)*D;
  A[25][16]=(0.0)*D;
  A[25][17]=(0.0)*D;
  A[25][18]=(0.0)*D;
  A[25][19]=(0.0)*D;
  A[25][20]=(0.0)*D;
  A[25][21]=(0.0)*D;
  A[25][22]=(0.0)*D;
  A[25][23]=(0.0)*D;
  A[25][24]=(-3.0000000000000000e+00)*D;
  A[25][25]=(6.5999999999999996e+00)*D;
  A[25][26]=(-3.0000000000000000e+00)*D;
  A[25][27]=(9.0000000000000002e-01)*D;
  A[25][28]=(3.2999999999999998e+00)*D;
  A[25][29]=(-6.2999999999999998e+00)*D;
  A[25][30]=(-2.1000000000000001e+00)*D;
  A[25][31]=(2.9999999999999999e-01)*D;
  A[25][32]=(-2.1000000000000001e+00)*D;
  A[25][33]=(-6.2999999999999998e+00)*D;
  A[25][34]=(3.2999999999999998e+00)*D;
  A[25][35]=(9.0000000000000002e-01)*D;
  A[26][0]=(0.0)*D;
  A[26][1]=(0.0)*D;
  A[26][2]=(0.0)*D;
  A[26][3]=(0.0)*D;
  A[26][4]=(0.0)*D;
  A[26][5]=(0.0)*D;
  A[26][6]=(0.0)*D;
  A[26][7]=(0.0)*D;
  A[26][8]=(0.0)*D;
  A[26][9]=(0.0)*D;
  A[26][10]=(0.0)*D;
  A[26][11]=(0.0)*D;
  A[26][12]=(0.0)*D;
  A[26][13]=(0.0)*D;
  A[26][14]=(0.0)*D;
  A[26][15]=(0.0)*D;
  A[26][16]=(0.0)*D;
  A[26][17]=(0.0)*D;
  A[26][18]=(0.0)*D;
  A[26][19]=(0.0)*D;
  A[26][20]=(0.0)*D;
  A[26][21]=(0.0)*D;
  A[26][22]=(0.0)*D;
  A[26][23]=(0.0)*D;
  A[26][24]=(-3.0000000000000000e+00)*D;
  A[26][25]=(-3.0000000000000000e+00)*D;
  A[26][26]=(6.5999999999999996e+00)*D;
  A[26][27]=(-2.9999999999999999e-01)*D;
  A[26][28]=(2.1000000000000001e+00)*D;
  A[26][29]=(2.1000000000000001e+00)*D;
  A[26][30]=(6.2999999999999998e+00)*D;
  A[26][31]=(-9.0000000000000002e-01)*D;
  A[26][32]=(-3.2999999999999998e+00)*D;
  A[26][33]=(3.2999999999999998e+00)*D;
  A[26][34]=(-6.2999999999999998e+00)*D;
  A[26][35]=(9.0000000000000002e-01)*D;
  A[27][0]=(0.0)*D;
  A[27][1]=(0.0)*D;
  A[27][2]=(0.0)*D;
  A[27][3]=(0.0)*D;
  A[27][4]=(0.0)*D;
  A[27][5]=(0.0)*D;
  A[27][6]=(0.0)*D;
  A[27][7]=(0.0)*D;
  A[27][8]=(0.0)*D;
  A[27][9]=(0.0)*D;
  A[27][10]=(0.0)*D;
  A[27][11]=(0.0)*D;
  A[27][12]=(0.0)*D;
  A[27][13]=(0.0)*D;
  A[27][14]=(0.0)*D;
  A[27][15]=(0.0)*D;
  A[27][16]=(0.0)*D;
  A[27][17]=(0.0)*D;
  A[27][18]=(0.0)*D;
  A[27][19]=(0.0)*D;
  A[27][20]=(0.0)*D;
  A[27][21]=(0.0)*D;
  A[27][22]=(0.0)*D;
  A[27][23]=(0.0)*D;
  A[27][24]=(9.0000000000000002e-01)*D;
  A[27][25]=(9.0000000000000002e-01)*D;
  A[27][26]=(-2.9999999999999999e-01)*D;
  A[27][27]=(4.7999999999999998e+00)*D;
  A[27][28]=(-2.3999999999999999e+00)*D;
  A[27][29]=(-2.3999999999999999e+00)*D;
  A[27][30]=(0.0)*D;
  A[27][31]=(-1.2000000000000000e+00)*D;
  A[27][32]=(1.2000000000000000e+00)*D;
  A[27][33]=(-1.2000000000000000e+00)*D;
  A[27][34]=(0.0)*D;
  A[27][35]=(1.2000000000000000e+00)*D;
  A[28][0]=(0.0)*D;
  A[28][1]=(0.0)*D;
  A[28][2]=(0.0)*D;
  A[28][3]=(0.0)*D;
  A[28][4]=(0.0)*D;
  A[28][5]=(0.0)*D;
  A[28][6]=(0.0)*D;
  A[28][7]=(0.0)*D;
  A[28][8]=(0.0)*D;
  A[28][9]=(0.0)*D;
  A[28][10]=(0.0)*D;
  A[28][11]=(0.0)*D;
  A[28][12]=(0.0)*D;
  A[28][13]=(0.0)*D;
  A[28][14]=(0.0)*D;
  A[28][15]=(0.0)*D;
  A[28][16]=(0.0)*D;
  A[28][17]=(0.0)*D;
  A[28][18]=(0.0)*D;
  A[28][19]=(0.0)*D;
  A[28][20]=(0.0)*D;
  A[28][21]=(0.0)*D;
  A[28][22]=(0.0)*D;
  A[28][23]=(0.0)*D;
  A[28][24]=(-6.2999999999999998e+00)*D;
  A[28][25]=(3.2999999999999998e+00)*D;
  A[28][26]=(2.1000000000000001e+00)*D;
  A[28][27]=(-2.3999999999999999e+00)*D;
  A[28][28]=(9.5999999999999996e+00)*D;
  A[28][29]=(-4.7999999999999998e+00)*D;
  A[28][30]=(2.3999999999999999e+00)*D;
  A[28][31]=(1.2000000000000000e+00)*D;
  A[28][32]=(-6.0000000000000000e+00)*D;
  A[28][33]=(-2.3999999999999999e+00)*D;
  A[28][34]=(-1.2000000000000000e+00)*D;
  A[28][35]=(0.0)*D;
  A[29][0]=(0.0)*D;
  A[29][1]=(0.0)*D;
  A[29][2]=(0.0)*D;
  A[29][3]=(0.0)*D;
  A[29][4]=(0.0)*D;
  A[29][5]=(0.0)*D;
  A[29][6]=(0.0)*D;
  A[29][7]=(0.0)*D;
  A[29][8]=(0.0)*D;
  A[29][9]=(0.0)*D;
  A[29][10]=(0.0)*D;
  A[29][11]=(0.0)*D;
  A[29][12]=(0.0)*D;
  A[29][13]=(0.0)*D;
  A[29][14]=(0.0)*D;
  A[29][15]=(0.0)*D;
  A[29][16]=(0.0)*D;
  A[29][17]=(0.0)*D;
  A[29][18]=(0.0)*D;
  A[29][19]=(0.0)*D;
  A[29][20]=(0.0)*D;
  A[29][21]=(0.0)*D;
  A[29][22]=(0.0)*D;
  A[29][23]=(0.0)*D;
  A[29][24]=(3.2999999999999998e+00)*D;
  A[29][25]=(-6.2999999999999998e+00)*D;
  A[29][26]=(2.1000000000000001e+00)*D;
  A[29][27]=(-2.3999999999999999e+00)*D;
  A[29][28]=(-4.7999999999999998e+00)*D;
  A[29][29]=(9.5999999999999996e+00)*D;
  A[29][30]=(1.2000000000000000e+00)*D;
  A[29][31]=(0.0)*D;
  A[29][32]=(2.3999999999999999e+00)*D;
  A[29][33]=(6.0000000000000000e+00)*D;
  A[29][34]=(-2.3999999999999999e+00)*D;
  A[29][35]=(-1.2000000000000000e+00)*D;
  A[30][0]=(0.0)*D;
  A[30][1]=(0.0)*D;
  A[30][2]=(0.0)*D;
  A[30][3]=(0.0)*D;
  A[30][4]=(0.0)*D;
  A[30][5]=(0.0)*D;
  A[30][6]=(0.0)*D;
  A[30][7]=(0.0)*D;
  A[30][8]=(0.0)*D;
  A[30][9]=(0.0)*D;
  A[30][10]=(0.0)*D;
  A[30][11]=(0.0)*D;
  A[30][12]=(0.0)*D;
  A[30][13]=(0.0)*D;
  A[30][14]=(0.0)*D;
  A[30][15]=(0.0)*D;
  A[30][16]=(0.0)*D;
  A[30][17]=(0.0)*D;
  A[30][18]=(0.0)*D;
  A[30][19]=(0.0)*D;
  A[30][20]=(0.0)*D;
  A[30][21]=(0.0)*D;
  A[30][22]=(0.0)*D;
  A[30][23]=(0.0)*D;
  A[30][24]=(-3.2999999999999998e+00)*D;
  A[30][25]=(-2.1000000000000001e+00)*D;
  A[30][26]=(6.2999999999999998e+00)*D;
  A[30][27]=(0.0)*D;
  A[30][28]=(2.3999999999999999e+00)*D;
  A[30][29]=(1.2000000000000000e+00)*D;
  A[30][30]=(9.5999999999999996e+00)*D;
  A[30][31]=(-2.3999999999999999e+00)*D;
  A[30][32]=(-4.7999999999999998e+00)*D;
  A[30][33]=(2.3999999999999999e+00)*D;
  A[30][34]=(-6.0000000000000000e+00)*D;
  A[30][35]=(1.2000000000000000e+00)*D;
  A[31][0]=(0.0)*D;
  A[31][1]=(0.0)*D;
  A[31][2]=(0.0)*D;
  A[31][3]=(0.0)*D;
  A[31][4]=(0.0)*D;
  A[31][5]=(0.0)*D;
  A[31][6]=(0.0)*D;
  A[31][7]=(0.0)*D;
  A[31][8]=(0.0)*D;
  A[31][9]=(0.0)*D;
  A[31][10]=(0.0)*D;
  A[31][11]=(0.0)*D;
  A[31][12]=(0.0)*D;
  A[31][13]=(0.0)*D;
  A[31][14]=(0.0)*D;
  A[31][15]=(0.0)*D;
  A[31][16]=(0.0)*D;
  A[31][17]=(0.0)*D;
  A[31][18]=(0.0)*D;
  A[31][19]=(0.0)*D;
  A[31][20]=(0.0)*D;
  A[31][21]=(0.0)*D;
  A[31][22]=(0.0)*D;
  A[31][23]=(0.0)*D;
  A[31][24]=(-9.0000000000000002e-01)*D;
  A[31][25]=(2.9999999999999999e-01)*D;
  A[31][26]=(-9.0000000000000002e-01)*D;
  A[31][27]=(-1.2000000000000000e+00)*D;
  A[31][28]=(1.2000000000000000e+00)*D;
  A[31][29]=(0.0)*D;
  A[31][30]=(-2.3999999999999999e+00)*D;
  A[31][31]=(4.7999999999999998e+00)*D;
  A[31][32]=(-2.3999999999999999e+00)*D;
  A[31][33]=(0.0)*D;
  A[31][34]=(1.2000000000000000e+00)*D;
  A[31][35]=(-1.2000000000000000e+00)*D;
  A[32][0]=(0.0)*D;
  A[32][1]=(0.0)*D;
  A[32][2]=(0.0)*D;
  A[32][3]=(0.0)*D;
  A[32][4]=(0.0)*D;
  A[32][5]=(0.0)*D;
  A[32][6]=(0.0)*D;
  A[32][7]=(0.0)*D;
  A[32][8]=(0.0)*D;
  A[32][9]=(0.0)*D;
  A[32][10]=(0.0)*D;
  A[32][11]=(0.0)*D;
  A[32][12]=(0.0)*D;
  A[32][13]=(0.0)*D;
  A[32][14]=(0.0)*D;
  A[32][15]=(0.0)*D;
  A[32][16]=(0.0)*D;
  A[32][17]=(0.0)*D;
  A[32][18]=(0.0)*D;
  A[32][19]=(0.0)*D;
  A[32][20]=(0.0)*D;
  A[32][21]=(0.0)*D;
  A[32][22]=(0.0)*D;
  A[32][23]=(0.0)*D;
  A[32][24]=(6.2999999999999998e+00)*D;
  A[32][25]=(-2.1000000000000001e+00)*D;
  A[32][26]=(-3.2999999999999998e+00)*D;
  A[32][27]=(1.2000000000000000e+00)*D;
  A[32][28]=(-6.0000000000000000e+00)*D;
  A[32][29]=(2.3999999999999999e+00)*D;
  A[32][30]=(-4.7999999999999998e+00)*D;
  A[32][31]=(-2.3999999999999999e+00)*D;
  A[32][32]=(9.5999999999999996e+00)*D;
  A[32][33]=(1.2000000000000000e+00)*D;
  A[32][34]=(2.3999999999999999e+00)*D;
  A[32][35]=(0.0)*D;
  A[33][0]=(0.0)*D;
  A[33][1]=(0.0)*D;
  A[33][2]=(0.0)*D;
  A[33][3]=(0.0)*D;
  A[33][4]=(0.0)*D;
  A[33][5]=(0.0)*D;
  A[33][6]=(0.0)*D;
  A[33][7]=(0.0)*D;
  A[33][8]=(0.0)*D;
  A[33][9]=(0.0)*D;
  A[33][10]=(0.0)*D;
  A[33][11]=(0.0)*D;
  A[33][12]=(0.0)*D;
  A[33][13]=(0.0)*D;
  A[33][14]=(0.0)*D;
  A[33][15]=(0.0)*D;
  A[33][16]=(0.0)*D;
  A[33][17]=(0.0)*D;
  A[33][18]=(0.0)*D;
  A[33][19]=(0.0)*D;
  A[33][20]=(0.0)*D;
  A[33][21]=(0.0)*D;
  A[33][22]=(0.0)*D;
  A[33][23]=(0.0)*D;
  A[33][24]=(2.1000000000000001e+00)*D;
  A[33][25]=(-6.2999999999999998e+00)*D;
  A[33][26]=(3.2999999999999998e+00)*D;
  A[33][27]=(-1.2000000000000000e+00)*D;
  A[33][28]=(-2.3999999999999999e+00)*D;
  A[33][29]=(6.0000000000000000e+00)*D;
  A[33][30]=(2.3999999999999999e+00)*D;
  A[33][31]=(0.0)*D;
  A[33][32]=(1.2000000000000000e+00)*D;
  A[33][33]=(9.5999999999999996e+00)*D;
  A[33][34]=(-4.7999999999999998e+00)*D;
  A[33][35]=(-2.3999999999999999e+00)*D;
  A[34][0]=(0.0)*D;
  A[34][1]=(0.0)*D;
  A[34][2]=(0.0)*D;
  A[34][3]=(0.0)*D;
  A[34][4]=(0.0)*D;
  A[34][5]=(0.0)*D;
  A[34][6]=(0.0)*D;
  A[34][7]=(0.0)*D;
  A[34][8]=(0.0)*D;
  A[34][9]=(0.0)*D;
  A[34][10]=(0.0)*D;
  A[34][11]=(0.0)*D;
  A[34][12]=(0.0)*D;
  A[34][13]=(0.0)*D;
  A[34][14]=(0.0)*D;
  A[34][15]=(0.0)*D;
  A[34][16]=(0.0)*D;
  A[34][17]=(0.0)*D;
  A[34][18]=(0.0)*D;
  A[34][19]=(0.0)*D;
  A[34][20]=(0.0)*D;
  A[34][21]=(0.0)*D;
  A[34][22]=(0.0)*D;
  A[34][23]=(0.0)*D;
  A[34][24]=(2.1000000000000001e+00)*D;
  A[34][25]=(3.2999999999999998e+00)*D;
  A[34][26]=(-6.2999999999999998e+00)*D;
  A[34][27]=(0.0)*D;
  A[34][28]=(-1.2000000000000000e+00)*D;
  A[34][29]=(-2.3999999999999999e+00)*D;
  A[34][30]=(-6.0000000000000000e+00)*D;
  A[34][31]=(1.2000000000000000e+00)*D;
  A[34][32]=(2.3999999999999999e+00)*D;
  A[34][33]=(-4.7999999999999998e+00)*D;
  A[34][34]=(9.5999999999999996e+00)*D;
  A[34][35]=(-2.3999999999999999e+00)*D;
  A[35][0]=(0.0)*D;
  A[35][1]=(0.0)*D;
  A[35][2]=(0.0)*D;
  A[35][3]=(0.0)*D;
  A[35][4]=(0.0)*D;
  A[35][5]=(0.0)*D;
  A[35][6]=(0.0)*D;
  A[35][7]=(0.0)*D;
  A[35][8]=(0.0)*D;
  A[35][9]=(0.0)*D;
  A[35][10]=(0.0)*D;
  A[35][11]=(0.0)*D;
  A[35][12]=(0.0)*D;
  A[35][13]=(0.0)*D;
  A[35][14]=(0.0)*D;
  A[35][15]=(0.0)*D;
  A[35][16]=(0.0)*D;
  A[35][17]=(0.0)*D;
  A[35][18]=(0.0)*D;
  A[35][19]=(0.0)*D;
  A[35][20]=(0.0)*D;
  A[35][21]=(0.0)*D;
  A[35][22]=(0.0)*D;
  A[35][23]=(0.0)*D;
  A[35][24]=(-2.9999999999999999e-01)*D;
  A[35][25]=(9.0000000000000002e-01)*D;
  A[35][26]=(9.0000000000000002e-01)*D;
  A[35][27]=(1.2000000000000000e+00)*D;
  A[35][28]=(0.0)*D;
  A[35][29]=(-1.2000000000000000e+00)*D;
  A[35][30]=(1.2000000000000000e+00)*D;
  A[35][31]=(-1.2000000000000000e+00)*D;
  A[35][32]=(0.0)*D;
  A[35][33]=(-2.3999999999999999e+00)*D;
  A[35][34]=(-2.3999999999999999e+00)*D;
  A[35][35]=(4.7999999999999998e+00)*D;
  int nbf = 36;

  pair<int,int> index;
  for (int i=0; i< nbf; i++) {
    index.first = ii_dof[i];
    for (int j=0; j< nbf; j++) {
      index.second = ii_dof[j];
      matrix[index] += A[i][j];
    }
  }

}

} // namespace pycc
