
#include <math.h>
#include <utility>
#include <map>
#include <ptv.h>
#include <simplex.h>
#include "DofT.h"
#include <ScalarFunction.h>
#include <VectorFunction.h>

using namespace std;

namespace pycc {



/* ------------- order 1 ---------------*/



void matrix_factory_mass_sigma_p_3D_order1 (map<pair<int,int>,double>& matrix,
         DofT<simplex_i,simplex_i_is_less>& i_dof,
         DofT<ptv,ptv_is_less>& j_dof,
         int element, double pp0[3], double pp1[3], double pp2[3], double pp3[3]){

   //variables

  double x0 = pp0[0]; double y0 = pp0[1]; double z0 = pp0[2];
  double x1 = pp1[0]; double y1 = pp1[1]; double z1 = pp1[2];
  double x2 = pp2[0]; double y2 = pp2[1]; double z2 = pp2[2];
  double x3 = pp3[0]; double y3 = pp3[1]; double z3 = pp3[2];

  double G00 = x1 - x0;
  double G10 = y1 - y0;
  double G20 = z1 - z0;

  double G01 = x2 - x0;
  double G11 = y2 - y0;
  double G21 = z2 - z0;

  double G02 = x3 - x0;
  double G12 = y3 - y0;
  double G22 = z3 - z0;

  double D =  G00*(G11*G22-G21*G12)
            - G01*(G10*G22-G20*G12)
            + G02*(G10*G21-G20*G11);




  double dptv0[3];
  dptv0[0] = G00+x0;
  dptv0[1] = G10+y0;
  dptv0[2] = z0+G20;
  ptv ptv0(3,dptv0);

  double dptv1[3];
  dptv1[0] = G01+x0;
  dptv1[1] = y0+G11;
  dptv1[2] = G21+z0;
  ptv ptv1(3,dptv1);

  double dptv2[3];
  dptv2[0] = G02+x0;
  dptv2[1] = G12+y0;
  dptv2[2] = G22+z0;
  ptv ptv2(3,dptv2);

  double dptv3[3];
  dptv3[0] = x0;
  dptv3[1] = y0;
  dptv3[2] = z0;
  ptv ptv3(3,dptv3);

  simplex s0(ptv2, ptv3, ptv0);
  simplex s1(ptv1, ptv2, ptv3);
  simplex s2(ptv3, ptv0, ptv1);
  simplex s3(ptv0, ptv1, ptv2);

  int ii_dof[36];  simplex_i dof0(s0,0,0);
  ii_dof[0] = i_dof.insert_dof(element, 0, dof0);
  simplex_i dof1(s0,1,0);
  ii_dof[1] = i_dof.insert_dof(element, 1, dof1);
  simplex_i dof2(s0,2,0);
  ii_dof[2] = i_dof.insert_dof(element, 2, dof2);
  simplex_i dof3(s1,0,0);
  ii_dof[3] = i_dof.insert_dof(element, 3, dof3);
  simplex_i dof4(s1,1,0);
  ii_dof[4] = i_dof.insert_dof(element, 4, dof4);
  simplex_i dof5(s1,2,0);
  ii_dof[5] = i_dof.insert_dof(element, 5, dof5);
  simplex_i dof6(s2,0,0);
  ii_dof[6] = i_dof.insert_dof(element, 6, dof6);
  simplex_i dof7(s2,1,0);
  ii_dof[7] = i_dof.insert_dof(element, 7, dof7);
  simplex_i dof8(s2,2,0);
  ii_dof[8] = i_dof.insert_dof(element, 8, dof8);
  simplex_i dof9(s3,0,0);
  ii_dof[9] = i_dof.insert_dof(element, 9, dof9);
  simplex_i dof10(s3,1,0);
  ii_dof[10] = i_dof.insert_dof(element, 10, dof10);
  simplex_i dof11(s3,2,0);
  ii_dof[11] = i_dof.insert_dof(element, 11, dof11);
  simplex_i dof12(s0,0,1);
  ii_dof[12] = i_dof.insert_dof(element, 12, dof12);
  simplex_i dof13(s0,1,1);
  ii_dof[13] = i_dof.insert_dof(element, 13, dof13);
  simplex_i dof14(s0,2,1);
  ii_dof[14] = i_dof.insert_dof(element, 14, dof14);
  simplex_i dof15(s1,0,1);
  ii_dof[15] = i_dof.insert_dof(element, 15, dof15);
  simplex_i dof16(s1,1,1);
  ii_dof[16] = i_dof.insert_dof(element, 16, dof16);
  simplex_i dof17(s1,2,1);
  ii_dof[17] = i_dof.insert_dof(element, 17, dof17);
  simplex_i dof18(s2,0,1);
  ii_dof[18] = i_dof.insert_dof(element, 18, dof18);
  simplex_i dof19(s2,1,1);
  ii_dof[19] = i_dof.insert_dof(element, 19, dof19);
  simplex_i dof20(s2,2,1);
  ii_dof[20] = i_dof.insert_dof(element, 20, dof20);
  simplex_i dof21(s3,0,1);
  ii_dof[21] = i_dof.insert_dof(element, 21, dof21);
  simplex_i dof22(s3,1,1);
  ii_dof[22] = i_dof.insert_dof(element, 22, dof22);
  simplex_i dof23(s3,2,1);
  ii_dof[23] = i_dof.insert_dof(element, 23, dof23);
  simplex_i dof24(s0,0,2);
  ii_dof[24] = i_dof.insert_dof(element, 24, dof24);
  simplex_i dof25(s0,1,2);
  ii_dof[25] = i_dof.insert_dof(element, 25, dof25);
  simplex_i dof26(s0,2,2);
  ii_dof[26] = i_dof.insert_dof(element, 26, dof26);
  simplex_i dof27(s1,0,2);
  ii_dof[27] = i_dof.insert_dof(element, 27, dof27);
  simplex_i dof28(s1,1,2);
  ii_dof[28] = i_dof.insert_dof(element, 28, dof28);
  simplex_i dof29(s1,2,2);
  ii_dof[29] = i_dof.insert_dof(element, 29, dof29);
  simplex_i dof30(s2,0,2);
  ii_dof[30] = i_dof.insert_dof(element, 30, dof30);
  simplex_i dof31(s2,1,2);
  ii_dof[31] = i_dof.insert_dof(element, 31, dof31);
  simplex_i dof32(s2,2,2);
  ii_dof[32] = i_dof.insert_dof(element, 32, dof32);
  simplex_i dof33(s3,0,2);
  ii_dof[33] = i_dof.insert_dof(element, 33, dof33);
  simplex_i dof34(s3,1,2);
  ii_dof[34] = i_dof.insert_dof(element, 34, dof34);
  simplex_i dof35(s3,2,2);
  ii_dof[35] = i_dof.insert_dof(element, 35, dof35);

  int    ij_dof[12];
  double jdof0[5];
  jdof0[0]=x0;  jdof0[1]=y0;  jdof0[2]=z0;
  jdof0[3] = 0.0; jdof0[4] = element;
  ptv jpdof0(5,jdof0);
  ij_dof[0] = j_dof.insert_dof(element,0,jpdof0);

  double jdof1[5];
  jdof1[0]=x0;  jdof1[1]=y0;  jdof1[2]=z0;
  jdof1[3] = 1.0; jdof1[4] = element;
  ptv jpdof1(5,jdof1);
  ij_dof[1] = j_dof.insert_dof(element,1,jpdof1);

  double jdof2[5];
  jdof2[0]=x0;  jdof2[1]=y0;  jdof2[2]=z0;
  jdof2[3] = 2.0; jdof2[4] = element;
  ptv jpdof2(5,jdof2);
  ij_dof[2] = j_dof.insert_dof(element,2,jpdof2);

  double jdof3[5];
  jdof3[0]=G00+x0;  jdof3[1]=G10+y0;  jdof3[2]=z0+G20;
  jdof3[3] = 0.0; jdof3[4] = element;
  ptv jpdof3(5,jdof3);
  ij_dof[3] = j_dof.insert_dof(element,3,jpdof3);

  double jdof4[5];
  jdof4[0]=G00+x0;  jdof4[1]=G10+y0;  jdof4[2]=z0+G20;
  jdof4[3] = 1.0; jdof4[4] = element;
  ptv jpdof4(5,jdof4);
  ij_dof[4] = j_dof.insert_dof(element,4,jpdof4);

  double jdof5[5];
  jdof5[0]=G00+x0;  jdof5[1]=G10+y0;  jdof5[2]=z0+G20;
  jdof5[3] = 2.0; jdof5[4] = element;
  ptv jpdof5(5,jdof5);
  ij_dof[5] = j_dof.insert_dof(element,5,jpdof5);

  double jdof6[5];
  jdof6[0]=G01+x0;  jdof6[1]=y0+G11;  jdof6[2]=G21+z0;
  jdof6[3] = 0.0; jdof6[4] = element;
  ptv jpdof6(5,jdof6);
  ij_dof[6] = j_dof.insert_dof(element,6,jpdof6);

  double jdof7[5];
  jdof7[0]=G01+x0;  jdof7[1]=y0+G11;  jdof7[2]=G21+z0;
  jdof7[3] = 1.0; jdof7[4] = element;
  ptv jpdof7(5,jdof7);
  ij_dof[7] = j_dof.insert_dof(element,7,jpdof7);

  double jdof8[5];
  jdof8[0]=G01+x0;  jdof8[1]=y0+G11;  jdof8[2]=G21+z0;
  jdof8[3] = 2.0; jdof8[4] = element;
  ptv jpdof8(5,jdof8);
  ij_dof[8] = j_dof.insert_dof(element,8,jpdof8);

  double jdof9[5];
  jdof9[0]=G02+x0;  jdof9[1]=G12+y0;  jdof9[2]=G22+z0;
  jdof9[3] = 0.0; jdof9[4] = element;
  ptv jpdof9(5,jdof9);
  ij_dof[9] = j_dof.insert_dof(element,9,jpdof9);

  double jdof10[5];
  jdof10[0]=G02+x0;  jdof10[1]=G12+y0;  jdof10[2]=G22+z0;
  jdof10[3] = 1.0; jdof10[4] = element;
  ptv jpdof10(5,jdof10);
  ij_dof[10] = j_dof.insert_dof(element,10,jpdof10);

  double jdof11[5];
  jdof11[0]=G02+x0;  jdof11[1]=G12+y0;  jdof11[2]=G22+z0;
  jdof11[3] = 2.0; jdof11[4] = element;
  ptv jpdof11(5,jdof11);
  ij_dof[11] = j_dof.insert_dof(element,11,jpdof11);


  double A[36][12];
  A[0][0]=(0.0)*D;
  A[0][1]=(1.4999999999999999e-01)*D;
  A[0][2]=(5.0000000000000003e-02)*D;
  A[0][3]=(0.0)*D;
  A[0][4]=(1.4999999999999999e-01)*D;
  A[0][5]=(5.0000000000000003e-02)*D;
  A[0][6]=(0.0)*D;
  A[0][7]=(1.4999999999999999e-01)*D;
  A[0][8]=(1.0000000000000001e-01)*D;
  A[0][9]=(0.0)*D;
  A[0][10]=(2.9999999999999999e-01)*D;
  A[0][11]=(5.0000000000000003e-02)*D;
  A[1][0]=(0.0)*D;
  A[1][1]=(-5.0000000000000003e-02)*D;
  A[1][2]=(-1.4999999999999999e-01)*D;
  A[1][3]=(0.0)*D;
  A[1][4]=(-5.0000000000000003e-02)*D;
  A[1][5]=(-1.4999999999999999e-01)*D;
  A[1][6]=(0.0)*D;
  A[1][7]=(-5.0000000000000003e-02)*D;
  A[1][8]=(-2.9999999999999999e-01)*D;
  A[1][9]=(0.0)*D;
  A[1][10]=(-1.0000000000000001e-01)*D;
  A[1][11]=(-1.4999999999999999e-01)*D;
  A[2][0]=(0.0)*D;
  A[2][1]=(-5.0000000000000003e-02)*D;
  A[2][2]=(5.0000000000000003e-02)*D;
  A[2][3]=(0.0)*D;
  A[2][4]=(-5.0000000000000003e-02)*D;
  A[2][5]=(5.0000000000000003e-02)*D;
  A[2][6]=(0.0)*D;
  A[2][7]=(-5.0000000000000003e-02)*D;
  A[2][8]=(1.0000000000000001e-01)*D;
  A[2][9]=(0.0)*D;
  A[2][10]=(-1.0000000000000001e-01)*D;
  A[2][11]=(5.0000000000000003e-02)*D;
  A[3][0]=(0.0)*D;
  A[3][1]=(5.0000000000000003e-02)*D;
  A[3][2]=(-5.0000000000000003e-02)*D;
  A[3][3]=(0.0)*D;
  A[3][4]=(5.0000000000000003e-02)*D;
  A[3][5]=(-5.0000000000000003e-02)*D;
  A[3][6]=(0.0)*D;
  A[3][7]=(5.0000000000000003e-02)*D;
  A[3][8]=(-1.0000000000000001e-01)*D;
  A[3][9]=(0.0)*D;
  A[3][10]=(1.0000000000000001e-01)*D;
  A[3][11]=(-5.0000000000000003e-02)*D;
  A[4][0]=(0.0)*D;
  A[4][1]=(-1.4999999999999999e-01)*D;
  A[4][2]=(-5.0000000000000003e-02)*D;
  A[4][3]=(0.0)*D;
  A[4][4]=(-1.4999999999999999e-01)*D;
  A[4][5]=(-5.0000000000000003e-02)*D;
  A[4][6]=(0.0)*D;
  A[4][7]=(-1.4999999999999999e-01)*D;
  A[4][8]=(-1.0000000000000001e-01)*D;
  A[4][9]=(0.0)*D;
  A[4][10]=(-2.9999999999999999e-01)*D;
  A[4][11]=(-5.0000000000000003e-02)*D;
  A[5][0]=(0.0)*D;
  A[5][1]=(5.0000000000000003e-02)*D;
  A[5][2]=(1.4999999999999999e-01)*D;
  A[5][3]=(0.0)*D;
  A[5][4]=(5.0000000000000003e-02)*D;
  A[5][5]=(1.4999999999999999e-01)*D;
  A[5][6]=(0.0)*D;
  A[5][7]=(5.0000000000000003e-02)*D;
  A[5][8]=(2.9999999999999999e-01)*D;
  A[5][9]=(0.0)*D;
  A[5][10]=(1.0000000000000001e-01)*D;
  A[5][11]=(1.4999999999999999e-01)*D;
  A[6][0]=(0.0)*D;
  A[6][1]=(-5.0000000000000003e-02)*D;
  A[6][2]=(0.0)*D;
  A[6][3]=(0.0)*D;
  A[6][4]=(-5.0000000000000003e-02)*D;
  A[6][5]=(2.0000000000000001e-01)*D;
  A[6][6]=(0.0)*D;
  A[6][7]=(-5.0000000000000003e-02)*D;
  A[6][8]=(5.0000000000000003e-02)*D;
  A[6][9]=(0.0)*D;
  A[6][10]=(-1.0000000000000001e-01)*D;
  A[6][11]=(0.0)*D;
  A[7][0]=(0.0)*D;
  A[7][1]=(-5.0000000000000003e-02)*D;
  A[7][2]=(2.0000000000000001e-01)*D;
  A[7][3]=(0.0)*D;
  A[7][4]=(-5.0000000000000003e-02)*D;
  A[7][5]=(0.0)*D;
  A[7][6]=(0.0)*D;
  A[7][7]=(-5.0000000000000003e-02)*D;
  A[7][8]=(5.0000000000000003e-02)*D;
  A[7][9]=(0.0)*D;
  A[7][10]=(-1.0000000000000001e-01)*D;
  A[7][11]=(0.0)*D;
  A[8][0]=(0.0)*D;
  A[8][1]=(1.4999999999999999e-01)*D;
  A[8][2]=(0.0)*D;
  A[8][3]=(0.0)*D;
  A[8][4]=(1.4999999999999999e-01)*D;
  A[8][5]=(0.0)*D;
  A[8][6]=(0.0)*D;
  A[8][7]=(1.4999999999999999e-01)*D;
  A[8][8]=(5.0000000000000003e-02)*D;
  A[8][9]=(0.0)*D;
  A[8][10]=(2.9999999999999999e-01)*D;
  A[8][11]=(2.0000000000000001e-01)*D;
  A[9][0]=(0.0)*D;
  A[9][1]=(0.0)*D;
  A[9][2]=(1.4999999999999999e-01)*D;
  A[9][3]=(0.0)*D;
  A[9][4]=(0.0)*D;
  A[9][5]=(1.4999999999999999e-01)*D;
  A[9][6]=(0.0)*D;
  A[9][7]=(2.0000000000000001e-01)*D;
  A[9][8]=(2.9999999999999999e-01)*D;
  A[9][9]=(0.0)*D;
  A[9][10]=(5.0000000000000003e-02)*D;
  A[9][11]=(1.4999999999999999e-01)*D;
  A[10][0]=(0.0)*D;
  A[10][1]=(0.0)*D;
  A[10][2]=(-5.0000000000000003e-02)*D;
  A[10][3]=(0.0)*D;
  A[10][4]=(2.0000000000000001e-01)*D;
  A[10][5]=(-5.0000000000000003e-02)*D;
  A[10][6]=(0.0)*D;
  A[10][7]=(0.0)*D;
  A[10][8]=(-1.0000000000000001e-01)*D;
  A[10][9]=(0.0)*D;
  A[10][10]=(5.0000000000000003e-02)*D;
  A[10][11]=(-5.0000000000000003e-02)*D;
  A[11][0]=(0.0)*D;
  A[11][1]=(2.0000000000000001e-01)*D;
  A[11][2]=(-5.0000000000000003e-02)*D;
  A[11][3]=(0.0)*D;
  A[11][4]=(0.0)*D;
  A[11][5]=(-5.0000000000000003e-02)*D;
  A[11][6]=(0.0)*D;
  A[11][7]=(0.0)*D;
  A[11][8]=(-1.0000000000000001e-01)*D;
  A[11][9]=(0.0)*D;
  A[11][10]=(5.0000000000000003e-02)*D;
  A[11][11]=(-5.0000000000000003e-02)*D;
  A[12][0]=(-1.4999999999999999e-01)*D;
  A[12][1]=(0.0)*D;
  A[12][2]=(-5.0000000000000003e-02)*D;
  A[12][3]=(-1.4999999999999999e-01)*D;
  A[12][4]=(0.0)*D;
  A[12][5]=(-1.0000000000000001e-01)*D;
  A[12][6]=(-1.4999999999999999e-01)*D;
  A[12][7]=(0.0)*D;
  A[12][8]=(-5.0000000000000003e-02)*D;
  A[12][9]=(-2.9999999999999999e-01)*D;
  A[12][10]=(0.0)*D;
  A[12][11]=(-5.0000000000000003e-02)*D;
  A[13][0]=(5.0000000000000003e-02)*D;
  A[13][1]=(0.0)*D;
  A[13][2]=(-5.0000000000000003e-02)*D;
  A[13][3]=(5.0000000000000003e-02)*D;
  A[13][4]=(0.0)*D;
  A[13][5]=(-1.0000000000000001e-01)*D;
  A[13][6]=(5.0000000000000003e-02)*D;
  A[13][7]=(0.0)*D;
  A[13][8]=(-5.0000000000000003e-02)*D;
  A[13][9]=(1.0000000000000001e-01)*D;
  A[13][10]=(0.0)*D;
  A[13][11]=(-5.0000000000000003e-02)*D;
  A[14][0]=(5.0000000000000003e-02)*D;
  A[14][1]=(0.0)*D;
  A[14][2]=(1.4999999999999999e-01)*D;
  A[14][3]=(5.0000000000000003e-02)*D;
  A[14][4]=(0.0)*D;
  A[14][5]=(2.9999999999999999e-01)*D;
  A[14][6]=(5.0000000000000003e-02)*D;
  A[14][7]=(0.0)*D;
  A[14][8]=(1.4999999999999999e-01)*D;
  A[14][9]=(1.0000000000000001e-01)*D;
  A[14][10]=(0.0)*D;
  A[14][11]=(1.4999999999999999e-01)*D;
  A[15][0]=(-5.0000000000000003e-02)*D;
  A[15][1]=(0.0)*D;
  A[15][2]=(2.0000000000000001e-01)*D;
  A[15][3]=(-5.0000000000000003e-02)*D;
  A[15][4]=(0.0)*D;
  A[15][5]=(5.0000000000000003e-02)*D;
  A[15][6]=(-5.0000000000000003e-02)*D;
  A[15][7]=(0.0)*D;
  A[15][8]=(0.0)*D;
  A[15][9]=(-1.0000000000000001e-01)*D;
  A[15][10]=(0.0)*D;
  A[15][11]=(0.0)*D;
  A[16][0]=(1.4999999999999999e-01)*D;
  A[16][1]=(0.0)*D;
  A[16][2]=(0.0)*D;
  A[16][3]=(1.4999999999999999e-01)*D;
  A[16][4]=(0.0)*D;
  A[16][5]=(5.0000000000000003e-02)*D;
  A[16][6]=(1.4999999999999999e-01)*D;
  A[16][7]=(0.0)*D;
  A[16][8]=(0.0)*D;
  A[16][9]=(2.9999999999999999e-01)*D;
  A[16][10]=(0.0)*D;
  A[16][11]=(2.0000000000000001e-01)*D;
  A[17][0]=(-5.0000000000000003e-02)*D;
  A[17][1]=(0.0)*D;
  A[17][2]=(0.0)*D;
  A[17][3]=(-5.0000000000000003e-02)*D;
  A[17][4]=(0.0)*D;
  A[17][5]=(5.0000000000000003e-02)*D;
  A[17][6]=(-5.0000000000000003e-02)*D;
  A[17][7]=(0.0)*D;
  A[17][8]=(2.0000000000000001e-01)*D;
  A[17][9]=(-1.0000000000000001e-01)*D;
  A[17][10]=(0.0)*D;
  A[17][11]=(0.0)*D;
  A[18][0]=(5.0000000000000003e-02)*D;
  A[18][1]=(0.0)*D;
  A[18][2]=(1.4999999999999999e-01)*D;
  A[18][3]=(5.0000000000000003e-02)*D;
  A[18][4]=(0.0)*D;
  A[18][5]=(2.9999999999999999e-01)*D;
  A[18][6]=(5.0000000000000003e-02)*D;
  A[18][7]=(0.0)*D;
  A[18][8]=(1.4999999999999999e-01)*D;
  A[18][9]=(1.0000000000000001e-01)*D;
  A[18][10]=(0.0)*D;
  A[18][11]=(1.4999999999999999e-01)*D;
  A[19][0]=(5.0000000000000003e-02)*D;
  A[19][1]=(0.0)*D;
  A[19][2]=(-5.0000000000000003e-02)*D;
  A[19][3]=(5.0000000000000003e-02)*D;
  A[19][4]=(0.0)*D;
  A[19][5]=(-1.0000000000000001e-01)*D;
  A[19][6]=(5.0000000000000003e-02)*D;
  A[19][7]=(0.0)*D;
  A[19][8]=(-5.0000000000000003e-02)*D;
  A[19][9]=(1.0000000000000001e-01)*D;
  A[19][10]=(0.0)*D;
  A[19][11]=(-5.0000000000000003e-02)*D;
  A[20][0]=(-1.4999999999999999e-01)*D;
  A[20][1]=(0.0)*D;
  A[20][2]=(-5.0000000000000003e-02)*D;
  A[20][3]=(-1.4999999999999999e-01)*D;
  A[20][4]=(0.0)*D;
  A[20][5]=(-1.0000000000000001e-01)*D;
  A[20][6]=(-1.4999999999999999e-01)*D;
  A[20][7]=(0.0)*D;
  A[20][8]=(-5.0000000000000003e-02)*D;
  A[20][9]=(-2.9999999999999999e-01)*D;
  A[20][10]=(0.0)*D;
  A[20][11]=(-5.0000000000000003e-02)*D;
  A[21][0]=(0.0)*D;
  A[21][1]=(0.0)*D;
  A[21][2]=(5.0000000000000003e-02)*D;
  A[21][3]=(0.0)*D;
  A[21][4]=(0.0)*D;
  A[21][5]=(1.0000000000000001e-01)*D;
  A[21][6]=(-2.0000000000000001e-01)*D;
  A[21][7]=(0.0)*D;
  A[21][8]=(5.0000000000000003e-02)*D;
  A[21][9]=(-5.0000000000000003e-02)*D;
  A[21][10]=(0.0)*D;
  A[21][11]=(5.0000000000000003e-02)*D;
  A[22][0]=(0.0)*D;
  A[22][1]=(0.0)*D;
  A[22][2]=(-1.4999999999999999e-01)*D;
  A[22][3]=(-2.0000000000000001e-01)*D;
  A[22][4]=(0.0)*D;
  A[22][5]=(-2.9999999999999999e-01)*D;
  A[22][6]=(0.0)*D;
  A[22][7]=(0.0)*D;
  A[22][8]=(-1.4999999999999999e-01)*D;
  A[22][9]=(-5.0000000000000003e-02)*D;
  A[22][10]=(0.0)*D;
  A[22][11]=(-1.4999999999999999e-01)*D;
  A[23][0]=(-2.0000000000000001e-01)*D;
  A[23][1]=(0.0)*D;
  A[23][2]=(5.0000000000000003e-02)*D;
  A[23][3]=(0.0)*D;
  A[23][4]=(0.0)*D;
  A[23][5]=(1.0000000000000001e-01)*D;
  A[23][6]=(0.0)*D;
  A[23][7]=(0.0)*D;
  A[23][8]=(5.0000000000000003e-02)*D;
  A[23][9]=(-5.0000000000000003e-02)*D;
  A[23][10]=(0.0)*D;
  A[23][11]=(5.0000000000000003e-02)*D;
  A[24][0]=(-5.0000000000000003e-02)*D;
  A[24][1]=(5.0000000000000003e-02)*D;
  A[24][2]=(0.0)*D;
  A[24][3]=(-5.0000000000000003e-02)*D;
  A[24][4]=(1.0000000000000001e-01)*D;
  A[24][5]=(0.0)*D;
  A[24][6]=(-1.0000000000000001e-01)*D;
  A[24][7]=(5.0000000000000003e-02)*D;
  A[24][8]=(0.0)*D;
  A[24][9]=(-5.0000000000000003e-02)*D;
  A[24][10]=(5.0000000000000003e-02)*D;
  A[24][11]=(0.0)*D;
  A[25][0]=(1.4999999999999999e-01)*D;
  A[25][1]=(5.0000000000000003e-02)*D;
  A[25][2]=(0.0)*D;
  A[25][3]=(1.4999999999999999e-01)*D;
  A[25][4]=(1.0000000000000001e-01)*D;
  A[25][5]=(0.0)*D;
  A[25][6]=(2.9999999999999999e-01)*D;
  A[25][7]=(5.0000000000000003e-02)*D;
  A[25][8]=(0.0)*D;
  A[25][9]=(1.4999999999999999e-01)*D;
  A[25][10]=(5.0000000000000003e-02)*D;
  A[25][11]=(0.0)*D;
  A[26][0]=(-5.0000000000000003e-02)*D;
  A[26][1]=(-1.4999999999999999e-01)*D;
  A[26][2]=(0.0)*D;
  A[26][3]=(-5.0000000000000003e-02)*D;
  A[26][4]=(-2.9999999999999999e-01)*D;
  A[26][5]=(0.0)*D;
  A[26][6]=(-1.0000000000000001e-01)*D;
  A[26][7]=(-1.4999999999999999e-01)*D;
  A[26][8]=(0.0)*D;
  A[26][9]=(-5.0000000000000003e-02)*D;
  A[26][10]=(-1.4999999999999999e-01)*D;
  A[26][11]=(0.0)*D;
  A[27][0]=(5.0000000000000003e-02)*D;
  A[27][1]=(-2.0000000000000001e-01)*D;
  A[27][2]=(0.0)*D;
  A[27][3]=(5.0000000000000003e-02)*D;
  A[27][4]=(-5.0000000000000003e-02)*D;
  A[27][5]=(0.0)*D;
  A[27][6]=(1.0000000000000001e-01)*D;
  A[27][7]=(0.0)*D;
  A[27][8]=(0.0)*D;
  A[27][9]=(5.0000000000000003e-02)*D;
  A[27][10]=(0.0)*D;
  A[27][11]=(0.0)*D;
  A[28][0]=(5.0000000000000003e-02)*D;
  A[28][1]=(0.0)*D;
  A[28][2]=(0.0)*D;
  A[28][3]=(5.0000000000000003e-02)*D;
  A[28][4]=(-5.0000000000000003e-02)*D;
  A[28][5]=(0.0)*D;
  A[28][6]=(1.0000000000000001e-01)*D;
  A[28][7]=(0.0)*D;
  A[28][8]=(0.0)*D;
  A[28][9]=(5.0000000000000003e-02)*D;
  A[28][10]=(-2.0000000000000001e-01)*D;
  A[28][11]=(0.0)*D;
  A[29][0]=(-1.4999999999999999e-01)*D;
  A[29][1]=(0.0)*D;
  A[29][2]=(0.0)*D;
  A[29][3]=(-1.4999999999999999e-01)*D;
  A[29][4]=(-5.0000000000000003e-02)*D;
  A[29][5]=(0.0)*D;
  A[29][6]=(-2.9999999999999999e-01)*D;
  A[29][7]=(-2.0000000000000001e-01)*D;
  A[29][8]=(0.0)*D;
  A[29][9]=(-1.4999999999999999e-01)*D;
  A[29][10]=(0.0)*D;
  A[29][11]=(0.0)*D;
  A[30][0]=(0.0)*D;
  A[30][1]=(-1.4999999999999999e-01)*D;
  A[30][2]=(0.0)*D;
  A[30][3]=(-2.0000000000000001e-01)*D;
  A[30][4]=(-2.9999999999999999e-01)*D;
  A[30][5]=(0.0)*D;
  A[30][6]=(-5.0000000000000003e-02)*D;
  A[30][7]=(-1.4999999999999999e-01)*D;
  A[30][8]=(0.0)*D;
  A[30][9]=(0.0)*D;
  A[30][10]=(-1.4999999999999999e-01)*D;
  A[30][11]=(0.0)*D;
  A[31][0]=(-2.0000000000000001e-01)*D;
  A[31][1]=(5.0000000000000003e-02)*D;
  A[31][2]=(0.0)*D;
  A[31][3]=(0.0)*D;
  A[31][4]=(1.0000000000000001e-01)*D;
  A[31][5]=(0.0)*D;
  A[31][6]=(-5.0000000000000003e-02)*D;
  A[31][7]=(5.0000000000000003e-02)*D;
  A[31][8]=(0.0)*D;
  A[31][9]=(0.0)*D;
  A[31][10]=(5.0000000000000003e-02)*D;
  A[31][11]=(0.0)*D;
  A[32][0]=(0.0)*D;
  A[32][1]=(5.0000000000000003e-02)*D;
  A[32][2]=(0.0)*D;
  A[32][3]=(0.0)*D;
  A[32][4]=(1.0000000000000001e-01)*D;
  A[32][5]=(0.0)*D;
  A[32][6]=(-5.0000000000000003e-02)*D;
  A[32][7]=(5.0000000000000003e-02)*D;
  A[32][8]=(0.0)*D;
  A[32][9]=(-2.0000000000000001e-01)*D;
  A[32][10]=(5.0000000000000003e-02)*D;
  A[32][11]=(0.0)*D;
  A[33][0]=(-1.4999999999999999e-01)*D;
  A[33][1]=(-5.0000000000000003e-02)*D;
  A[33][2]=(0.0)*D;
  A[33][3]=(-1.4999999999999999e-01)*D;
  A[33][4]=(-1.0000000000000001e-01)*D;
  A[33][5]=(0.0)*D;
  A[33][6]=(-2.9999999999999999e-01)*D;
  A[33][7]=(-5.0000000000000003e-02)*D;
  A[33][8]=(0.0)*D;
  A[33][9]=(-1.4999999999999999e-01)*D;
  A[33][10]=(-5.0000000000000003e-02)*D;
  A[33][11]=(0.0)*D;
  A[34][0]=(5.0000000000000003e-02)*D;
  A[34][1]=(1.4999999999999999e-01)*D;
  A[34][2]=(0.0)*D;
  A[34][3]=(5.0000000000000003e-02)*D;
  A[34][4]=(2.9999999999999999e-01)*D;
  A[34][5]=(0.0)*D;
  A[34][6]=(1.0000000000000001e-01)*D;
  A[34][7]=(1.4999999999999999e-01)*D;
  A[34][8]=(0.0)*D;
  A[34][9]=(5.0000000000000003e-02)*D;
  A[34][10]=(1.4999999999999999e-01)*D;
  A[34][11]=(0.0)*D;
  A[35][0]=(5.0000000000000003e-02)*D;
  A[35][1]=(-5.0000000000000003e-02)*D;
  A[35][2]=(0.0)*D;
  A[35][3]=(5.0000000000000003e-02)*D;
  A[35][4]=(-1.0000000000000001e-01)*D;
  A[35][5]=(0.0)*D;
  A[35][6]=(1.0000000000000001e-01)*D;
  A[35][7]=(-5.0000000000000003e-02)*D;
  A[35][8]=(0.0)*D;
  A[35][9]=(5.0000000000000003e-02)*D;
  A[35][10]=(-5.0000000000000003e-02)*D;
  A[35][11]=(0.0)*D;


  pair<int,int> index;
  for (int i=0; i< 36; i++) {
    index.first = ii_dof[i];
    for (int j=0; j< 12; j++) {
      index.second = ij_dof[j];
      matrix[index] += A[i][j];
    }
  }

}

} // namespace pycc
