#
# This is an example file, showing how to generate ufc element code for some basic forms.
#

#from swiginac import *
import SyFi
import ufccodegen
from ufccodegen.symbolic_utils import inner, mul, grad, div
from ufccodegen import MatrixForm, VectorForm, ScalarForm
from ufccodegen import compile_form, gen_form_code

#ufccodegen.options.include_from = "local"
#ufccodegen.options.include_from = "PyCC"
ufccodegen.options.include_from = "SyFi"

def stiffness_with_M(u, v, M, G, Ginv):
    Du = grad(u, Ginv)
    Dv = grad(v, Ginv)
    return inner( mul(M,Du), Dv )

def rhs(v, f, G, Ginv):
    return inner(f, v)

def H1norm(u, G, Ginv):
    Du = grad(u, Ginv)
    return inner(u,u) + inner(Du, Du)

nsd = 2
SyFi.initSyFi(nsd)

polygon = SyFi.newReferenceSimplex(nsd)
fe0     = SyFi.P0(polygon)
fe1     = SyFi.LagrangeFE(polygon, 1)

A  = MatrixForm(stiffness_with_M)
b  = VectorForm(rhs)
H1 = ScalarForm(H1norm)

gen_form_code(A,  [fe1, fe1, fe0])
gen_form_code(b,  fe1)
gen_form_code(H1, fe1)

# compile the extension modules
Ac  = compile_form(A,  [fe1, fe1, fe0])
bc  = compile_form(b,  fe1)
H1c = compile_form(H1, fe1)
print Ac.rank(), bc.rank(), H1c.rank()

