from code_generator import code_generator
import swiginac

import ufc

# TODO: Add possiblity of runtime variables. Time, timestep, material parameters etc.

def mat_shape(e):
    if e.rows() != 1 and e.cols() != 1:
        return (e.rows(), e.cols())
    else:
        return (e.nops(), )

def parse_expression(e):
    """Convert an object to a list of function strings."""
    # try basic string or tuple of strings:
    if isinstance(e, str):
        shape = tuple()
        return [e] # scalar
    elif isinstance(e, tuple) or isinstance(e, list):
        shape = (len(e),)
        return e # vector, assuming all elements of e are strings
        #expstr = []
        #for ex in e:
        #    if isinstance(ex, str):
        #        expstr += [ex]
        #    else:
        #        expstr += [ex.printc()]
        #return expstr
    # try swiginac types:
    if isinstance(e, swiginac.basic):
        e = e.evalm()
        if isinstance(e, swiginac.matrix):
            shape = mat_shape(e)
            return [e.op(i).printc() for i in range(e.nops())] # matrix
        elif isinstance(e, swiginac.lst):
            shape = (e.nops(),)
            return [e.op(i).printc() for i in range(e.nops())]  # vector
        else:
            shape = tuple()
            return [e.printc()] # scalar
    # we're out of luck...
    raise "Invalid expression type in ufccodegen.function.parse_expression."


def gen_dimension_body(shape):
    if len(shape) == 1:
        return "    return %d;" % shape[0]
    code = ""
    if len(shape) > 1:
        code += "    switch(i)\n"
        code += "    {\n"
        code += "\n".join([ "    case %d: return %d;" % (i, shape[i]) for i in range(len(shape)) ])
        code += "\n"
        code += "    }\n"
    code += '    throw std::runtime_error("Invalid dimension axis.");\n'
    code += '    return 0;\n'
    return code


class function(code_generator):
    """Simple class to generate code for ufc functions."""
    def __init__(self, name, expression):
        self.name       = name
        self.classname  = "function_" + name
        self.expression = expression
    
    def generate_header(self):
        expstr = parse_expression(self.expression)
        num_expr = len(expstr)
        
        self.evaluate  = "    const double x=coordinates[0], y=coordinates[1], z=coordinates[2];\n"
        self.evaluate += "\n".join( ["    values[%d] = %s;" % (i, expstr[i]) for i in range(len(expstr)) ] )
        return ufc.function_header_combined % self.__dict__
    
    def generate_code(self):
        return ""

