
## TODO: handling 1D rules, several sets
##quad_table_1D        = load_table("", 1)
#quad_table_simplex2D = load_table("simplex", 2)
#quad_table_simplex3D = load_table("simplex", 3)
#quad_table_cube2D    = load_table("cube", 2)
#quad_table_cube3D    = load_table("cube", 3)

class QuadRule:
    def __init__(self, n, points, weights, comment, order, nsd):
        self.n       = n
        self.points  = points
        self.weights = weights
        self.comment = comment
        self.order   = order
        self.nsd     = nsd
    
    def scale(self, offset, scale):
        ws = scale**self.nsd
        self.weights = [ w*ws for w in self.weights ]
        self.points  = [ [x*scale+offset for x in p] for p in self.points ]
    
    def __str__(self):
        return \
"""Description: %(comment)s
n       = %(n)d
points  = %(points)s
weights = %(weights)s
order   = %(order)d""" % self.__dict__



def parse_table(table, nsd):
    lines = table.split('\n')
    rules = []
    i = 0
    while(i<len(lines)):
        n = int(lines[i])
        i += 1
        points  = []
        weights = []
        for j in range(n):
            values   = lines[i].split()
            points  += [ map(float, values[:nsd]) ]
            weights += [ float(values[nsd]) ]
            i += 1
        comment = lines[i].strip()
        i += 2
        order = int(comment.split('=')[-1].split()[-1])
        rules += [ QuadRule(n, points, weights, comment, order, nsd) ]
    return rules



# TODO: same scale for all geometries?
def scale_table(rules):
    point_offset = 0.5
    point_scale  = 0.5
    for rule in rules:
        rule.scale(point_offset, point_scale)
    return rules 


import os.path

def load_table(geometry, nsd):
    fn = "quad_table_%s%dD.txt" % (geometry, nsd)
    fn = os.path.join( os.path.dirname(__file__), "quad_tables", fn)
    tables = open(fn).read()
    tables = parse_table(tables, nsd)
    tables = scale_table(tables)
    return tables



def find_quadrature_rule(order, nsd, geometry='simplex'):
    table = load_table(geometry, nsd)
    for r in table:
        if r.order == order:
            return r
    raise "Found no rule for a %dD %s with order %d" % (nsd, geometry, order)



def gen_quadrature_code(rule, inner_code):
    code  = "\n"
    code += "  const double quad_points[%d][%d] = \n" % (rule.n, rule.nsd)
    code += "    {\n"
    code += ",\n".join( [ "      { %s }" % (", ".join(map(str,p))) for p in rule.points ] )
    code += "\n    };\n"
    code += "\n"
    code += "  const double quad_weights[%d] =\n" % (rule.n)
    code += "    {\n"
    code += "      " + ", ".join( map(str, rule.weights) )
    code += "\n    };\n"
    code += "\n"
    code += "  for(int iq=0; iq<%d; iq++)\n" % rule.n
    code += "  {\n"
    for i in range(rule.nsd):
        code += "    const double %s = quad_points[iq][%d];\n" % ( ('x','y','z')[i], i )
    code += "    const double quad_weight_detG = quad_weights[iq] * detG;\n"
    code += inner_code
    code += "  }\n"
    code += "\n"
    return code



if __name__ == '__main__':
    inner_code = "    // Compute A here\n"
    
    order = 6
    nsd   = 2
    
    rule  = find_quadrature_rule(order, nsd)
    code  = gen_quadrature_code(rule, inner_code)
    
    print code

