import os
import os.path
import shutil

import Instant

import code_generator
import options
from function import function
from form import form

#   if dir_is_local:
#       a = '"'; b = '"'
#   else:
#       a = '<'; b = '>'
#   return "\n".join([ "#include " + a + dof_tools_dir + f + b  for f in include_headers ])


def generate_ufc_code_files__(el_ten, codedir):
    orig_dir = os.getcwd()
    if not os.path.isdir(codedir):
        os.mkdir(codedir)
    os.chdir(codedir)
    # Build dictionaries with unique sets of dof_map and finite_element objects.
    m = el_ten.rank + el_ten.num_coefficients
    nm_dict = {}
    fe_dict = {}
    for i in xrange(m):
        nm = el_ten.create_dof_map(i)
        fe = el_ten.create_finite_element(i)
        nm_dict[nm.signature] = nm
        fe_dict[fe.signature] = fe
    # Time to generate some code:
    system_includes = ["stdexcept", "math.h", "ufc.h"] + options.get_system_includes()
    local_includes = [] + options.get_local_includes()
    if options.use_local_includes():
        for f in options.get_tool_files():
            shutil.copy(f, os.path.join("./", os.path.basename(f)))
    cfiles = []
    hfiles = []
    def gen_code_(cg):
        hcode, ccode = code_generator.generate_code(cg.classname, cg, system_includes, local_includes, namespace=options.get_namespace())
                                 #comment=UfcComment, using=[], do_include_header=False
        fh, fc = cg.classname+".h", cg.classname+".cpp"
        open(fh, 'w').write(hcode)
        open(fc, 'w').write(ccode)
        return fh, fc
    for cg in nm_dict.values():
        fh, fc = gen_code_(cg)
        hfiles += [fh]; cfiles += [fc]
    for cg in fe_dict.values():
        fh, fc = gen_code_(cg)
        hfiles += [fh]; cfiles += [fc]
    # the element tensor depends on all the generated classes:
    local_includes += hfiles
    fh, fc = gen_code_(el_ten)
    hfiles += [fh]; cfiles += [fc]
    os.chdir(orig_dir)
    return hfiles, cfiles


def gen_form_code(user_form, fe_list, integration_mode='symbolic', quad_order=-1, codedir="generated_code"):
    """Generates ufc code for the given form and elements and writes it to files.
       Returns a two-tuple with lists of the header and source files generated."""
    # make code generator for user_form
    cell_itg      = None
    ext_facet_itg = None
    int_facet_itg = None
    if user_form.has_interior_integrand():        cell_itg      = user_form.interior_integrand
    if user_form.has_boundary_integrand():        ext_facet_itg = user_form.boundary_integrand
    #if user_form.has_interior_facet_integrand():  int_facet_itg = user_form.interior_facet_integrand  # TODO: update Form names
    form_codegen = form(user_form.name,
                        user_form.rank, user_form.num_coefficients,
                        fe_list,
                        cell_itg, ext_facet_itg, int_facet_itg,
                        integration_mode, quad_order)
    # generate complete ufc code for this form
    hfiles, cfiles = generate_ufc_code_files__(form_codegen, codedir)
    return (hfiles, cfiles, form_codegen.classname)


def compile_form(user_form, fe_list, integration_mode='symbolic', quad_order=-1):
    """Generates ufc code for the given form and elements and writes it to files.
       Then compiles the sources as an extension module and returns an ufc
       object that can be used for further FEM assembly."""
    orig_dir = os.getcwd()
    module_name = "user_form_" + user_form.name
    hfiles, cfiles, form_classname = gen_form_code(user_form, fe_list, integration_mode, quad_order, codedir=module_name)
    # compile extension module
    pkgs = options.get_tool_pkgs() + ["ufc-1"]
    (include_dirs, flags, libs, libdirs) = Instant.header_and_libs_from_pkgconfig(*pkgs)
    #cfiles += filter(lambda s: s.has(".cpp"), options.get_tool_files()) # FIXME
    system_headers = ["math.h", "stdexcept", "iostream", "ufc.h"] + options.get_system_includes()
    local_headers  = hfiles + options.get_local_includes()
    Instant.create_extension(module=module_name,
                             wrap_headers=hfiles, sources=cfiles,
                             headers=system_headers, local_headers=hfiles,
                             include_dirs = include_dirs, library_dirs = libdirs,
                             libraries = options.get_tool_libs(), cppargs = flags)
    # import and create ufc form object
    exec("import %s" % module_name)
    ufc_form = eval("%s.%s()" % (module_name, form_classname) )
    os.chdir(orig_dir)
    return ufc_form


#def gen_function_code(expression, name, codedir="generated_code"):
#    system_includes = ["math.h", "ufc.h"]
#    local_includes  = []
#    cgen = function(name, expression)
#    basename = "function_" + name
#    hcode, ccode = code_generator.generate_code(basename, cgen, system_includes, local_includes, using=["std"])
#    return hcode

def abs_ufc_h_path():
    (include_dirs, flags, libs, libdirs) = Instant.header_and_libs_from_pkgconfig("ufc-1")
    if len(include_dirs) != 1:
        raise "Need one include dir for ufc.h defined by pkgconfig."
    return os.path.join(include_dirs[0], "ufc.h")

def compile_function(expression, name):
    """Generates code for a ufc::function, and uses Instant to wrap it with SWIG and compile a Python module.
       Returns an instance of the compiled functor object. The expression can be a C++ expression string,
       a list or tuple of strings, a scalar swiginac expression, swiginac.matrix or swiginac.lst."""
    orig_dir = os.getcwd()
    
    # generate code
    cgen = function(name, expression)
    basename = "function_" + name
    hcode, ccode = code_generator.generate_code(basename, cgen, [], [], using=["std"])
    
    # setup extension module configs
    (include_dirs, flags, libs, libdirs) = Instant.header_and_libs_from_pkgconfig("ufc-1")
    module_name    = "user_function_" + name
    system_headers = ["math.h", "stdexcept", "iostream", "ufc.h"]
    wrap_headers   = [abs_ufc_h_path()]
    
    # compile extension module
    Instant.create_extension(code         = hcode,
                             module       = module_name,
                             headers      = system_headers,
                             wrap_headers = wrap_headers,
                             include_dirs = include_dirs,
                             cppargs      = flags)
    
    # import and create ufc form object
    exec("import %s" % module_name)
    obj = eval("%s.%s()" % (module_name, cgen.classname) )
    os.chdir(orig_dir)
    return obj


if __name__ == '__main__':
    import swiginac as s
    
    x = s.symbol("x")
    y = s.symbol("y")
    z = s.symbol("z")
    t = s.symbol("t")
    
    m = s.matrix(2, 2)
    m.set(0, 0, 1*s.sin(x*y))
    m.set(0, 1, 2*s.sin(x*y))
    m.set(1, 0, 3*s.sin(x*y))
    m.set(1, 1, 4*s.sin(x*y))
    
    print "Expression:"
    print m
    print "Generated code:"
    print function("test_function", m).generate_header()
    print "Compiling:"
    f = compile_function(m, "test_function")
    print ""
    print "Compiled object: ", f
    print "                 ", f.evaluate
    print ""

