#include "DiscontinuousLagrangeFE.h"
#include "ElementComputations.h"

using std::cout;
using std::endl;

namespace SyFi {


DiscontinuousLagrangeFE:: DiscontinuousLagrangeFE(Polygon& p, int order) : LagrangeFE(p,order) {
	compute_basis_functions(); 
} 

DiscontinuousLagrangeFE:: DiscontinuousLagrangeFE() : LagrangeFE() {
    element = 0; 
    description = "DiscontinuousLagrangeFE"; 
}



void DiscontinuousLagrangeFE:: compute_basis_functions() { 

    // remove previously computed basis functions and dofs
    Ns.clear(); 
    dofs.clear();

    if ( order < 1 ) {
        throw(std::logic_error("Discontinuous Lagrangian elements must be of order 1 or higher."));
    }


    if ( p == NULL ) {
        throw(std::logic_error("You need to set a polygon before the basisfunctions can be computed"));
    }


    //FIXME should have element defined somehow other than 
    //setting it to zero 
    //
    //It could be a symbol 'e' instead ?  


    LagrangeFE:: compute_basis_functions(); 
    for (int i=0; i< dofs.size(); i++) { 
        dofs[i] = GiNaC::lst(dofs[i], element); 
    }

    description = "Discontinuous" +  LagrangeFE:: str(); 
}




void DiscontinuousLagrangeFE:: set_element_number(int element_) {
    element = element_; 
}



// ------------VectorDiscontinuousLagrangeFE --- 


VectorDiscontinuousLagrangeFE:: VectorDiscontinuousLagrangeFE(Polygon& p, int order) : VectorLagrangeFE(p,order) {
	compute_basis_functions(); 
} 

VectorDiscontinuousLagrangeFE:: VectorDiscontinuousLagrangeFE() : 
    VectorLagrangeFE() 
{
        element = 0; 
        description = "DiscontinuousLagrangeFE"; 
}





void VectorDiscontinuousLagrangeFE:: compute_basis_functions(){ 

    // remove previously computed basis functions and dofs
    Ns.clear(); 
    dofs.clear();


    VectorLagrangeFE:: compute_basis_functions(); 

    for (int i=0; i< dofs.size(); i++) { 
        dofs[i] = GiNaC::lst(dofs[i], element); 
    }


    description = "Discontinuous" +  VectorLagrangeFE:: str(); 
}


void VectorDiscontinuousLagrangeFE:: set_size(int size_) {
    VectorLagrangeFE::set_size(size_);  
}


void VectorDiscontinuousLagrangeFE:: set_element_number(int element_) {
    element = element_; 
}


} // namespace SyFi  



