#include "ExpressionSimplifier.h"
#include "ExpressionSimplifierVisitor.h"
#include "ExpressionCollection.h"

#include <sstream>
#include <iostream>
#include "SyFi.h"

using namespace std;
using namespace GiNaC;
using namespace SyFi;

namespace SyFi
{

// structure for holding various temporary information about an expression
class symexdata
{
public:
    symexdata(const GiNaC::symbol & s_, const GiNaC::ex & e_, int mark_=0): s(s_), e(e_), mark(mark_), is_polynomial(false) {}

    GiNaC::symbol s;
    GiNaC::ex e;

    int mark;
    bool is_polynomial;
};

typedef std::list<symexdata> symexdatalist;

/*
class NoFuncVisitor:
    public GiNaC::visitor,
    public GiNaC::basic,
    public GiNaC::power,
    public GiNaC::function
{
    symexdatalist sel;

public:
    void visit(basic & b)
    {
    }

    void visit(function & f)
    {
    }

    void visit(power & p)
    {
    }

    const symexdatalist & getExpressions() { return sel; }
};
*/

/*
class TempVariableVisitor:
    public GiNaC::visitor,
    public GiNaC::basic,
    public GiNaC::power
{
    symexdatalist sel;

public:
    void visit(basic & b)
    {
    }

    void visit(power & p)
    {
    }

    const symexdatalist & getExpressions() { return sel; }
};
*/


/*
 * Mark all list items with given value.
 */
/*
void mark_all(symexdatalist & src, int value)
{
    symexdatalist & sel = src;
    for(symexdatalist::iterator it=sel.begin(); it!=sel.end(); it++)
    {
        it->mark = value;
    }
}
*/


/*
 * Traverse all expressions in list with given visitor.
 */
/*
void traverse_all(visitor & v, symexdatalist & sel)
{
    for(symexdatalist::iterator it=sel.begin(); it!=sel.end(); it++)
    {
        if( it->mark > 0 )
        {
            it->e.traverse(v);

            it->mark = 1;
        }
    }
}
*/


ExpressionSimplifier::ExpressionSimplifier(const string & _tempsymbolbasename, int initialsymbolnumber):
    tsh(_tempsymbolbasename, initialsymbolnumber),
    output(tsh)
{
}


/*
 * Add expression associated with a symbol
 */
void ExpressionSimplifier::add(const symbol & s, ex  e)
{
    input.push_back( symexpair(s,e) );
}


void ExpressionSimplifier::add(const list<symexpair> & selist)
{
    // TODO: test this
    input.insert(input.end(), selist.begin(), selist.end());
}



/*
 * Convert all added expressions to a more efficient form,
 * adding temporary variables as necessary.
 */
void ExpressionSimplifier::simplify_old()
{
    ExStats es_before;
    ExStats es_after;
    
    symexdatalist templist;
    
    // convert input list to new list while doing some preprocessing
    list<symexpair>::iterator iit = input.begin();
    for(; iit != input.end(); iit++)
    {
        const symbol & s = iit->first;
        const ex     & e = iit->second;
        
        // count operations before simplifications
        es_before += count_ops(e);
        
        // TODO: remove functions and inverses from e and append their
        //       arguments as subexpressions to templist before e,
        //       while marking the new subexpressions that include functions
        
        symexdata sed(s,e);
        sed.is_polynomial = false;
        templist.push_back( sed );
    }
    
    // make squarefree decomposition of all expressions we can
    for(symexdatalist::iterator tit=templist.begin(); tit!=templist.end(); tit++)
    {
        symbol s = tit->s;
        ex     e = tit->e;
        
        if(true) //tit->is_polynomial) // TODO
        {
            lst syms;
            syms = x,y,z;  // TODO: include more factorization variables in syms, perhaps the most used ones
            try {
                ex en = normal(e);
                ex es = sqrfree(e, syms);

                int ie = count_ops(e).flops;
                int in = count_ops(en).flops;
                int is = count_ops(es).flops;
                if(ie >= in)
                {
                    e = (ie >= is) ? e: es;
                }
                else
                {
                    e = (in >= is) ? en: es;
                }
            }
            catch(...)
            {
                e = tit->e;
            }
            // update expression
            //cout << tit->e << " = " << e << endl;
            tit->e = e;
        }
    }
    
    // TODO: get list of all symbols with max degree of each
    // TODO: substitute high degree powers with optimal set of helper variables
    //       (a^n  =>  n = sum_i c_i 2^i, c_i = 1 or 0)
    
    // perform the full tree traversal with operation-level substitutions
    ExpressionSimplifierVisitor esv(tsh, output);
    symexdatalist & esvinput = templist;
    for(symexdatalist::iterator it=esvinput.begin(); it!=esvinput.end(); it++)
    {
        esv.simplify(it->s, it->e);
    }
    
    // TODO: build some kind of graph for better optimization?
    // TODO: remove temporary variables used less than twice
    
    // count operations after simplifications
    list<symexpair> & selist = output.get_symex_list();
    for(list<symexpair>::iterator seit=selist.begin(); seit!=selist.end(); seit++)
    {
        const ex & e = seit->second;
        es_after += count_ops(e);
    }
    
    /*
    cout << "Flops before/after: \t\t\t\t" << es_before.flops << " / " << es_after.flops
         << " = " << (double(es_before.flops) / double(es_after.flops)) << endl;
    cout << "Number of symbols:  \t\t\t\t" << selist.size() << endl;
    */
}

/*
 * Convert all added expressions to a more efficient form,
 * adding temporary variables as necessary.
 */
void ExpressionSimplifier::simplify()
{
    ExStats es_before;
    ExStats es_after;
    
    // count operations before simplifications
    list<symexpair>::iterator iit = input.begin();
    for(; iit != input.end(); iit++)
    {
        const symbol & s = iit->first;
        const ex     & e = iit->second;
        es_before += count_ops(e);
    }
    
    // simplify!
    ExpressionSimplifierVisitor esv(tsh, output);
    for(list<symexpair>::iterator it=input.begin(); it!=input.end(); it++)
    {
        esv.simplify(it->first, it->second);
    }
    
    // count operations after simplifications
    list<symexpair> & selist = output.get_symex_list();
    for(list<symexpair>::iterator seit=selist.begin(); seit!=selist.end(); seit++)
    {
        const ex & e = seit->second;
        es_after += count_ops(e);
    }
    
    /*
    cout << "Flops before/after: " << es_before.flops << " / " << es_after.flops
         << " = " << (double(es_before.flops) / double(es_after.flops)) << endl;
    cout << "Number of symbols: " << selist.size() << endl;
    */
}

/*
    NoFuncVisitor nfv;
    traverse_all(nfv, raw);
    nofunc = nfv.getExpressions();

    TempVariableVisitor tvv;
    traverse_all(tvv, nofunc);
    finished = tvv.getExpressions();
*/

} // namespace SyFi
