#ifndef __ExpressionSimplifierVisitor_h__
#define __ExpressionSimplifierVisitor_h__


#include <string>
#include <list>
#include <ginac/ginac.h>

#include "TempSymbolHandler.h"
#include "ExpressionCollection.h"

namespace SyFi
{

class ExpressionSimplifierVisitor:
    public GiNaC::visitor,
    public GiNaC::numeric::visitor,
    public GiNaC::constant::visitor,
    public GiNaC::symbol::visitor,
    public GiNaC::power::visitor,
    public GiNaC::add::visitor,
    public GiNaC::mul::visitor,
    public GiNaC::function::visitor,
    public GiNaC::basic::visitor
{
private:
    TempSymbolHandler & tsh;
    ExpressionCollection & ec;

    inline const GiNaC::ex & doVisit(const GiNaC::ex & e);
    GiNaC::ex   result;

public:
    void visit(const GiNaC::numeric & e);
    void visit(const GiNaC::constant & e);
    void visit(const GiNaC::symbol & e);
    void visit(const GiNaC::power & e);
    void visit(const GiNaC::add & e);
    void visit(const GiNaC::mul & e);
    void visit(const GiNaC::function & e);
    void visit(const GiNaC::basic & e);

public:
    ExpressionSimplifierVisitor(TempSymbolHandler & tsh_, ExpressionCollection & ec_);

    /*
     * Simplify the passed expression and insert it in the collection
     * referenced by the passed symbol.
     */
    void simplify(GiNaC::symbol s, const GiNaC::ex & e);

    /*
     * Simplify the passed expression and return the temporary symbol
     * it can be referenced by in the collection.
     */
    GiNaC::ex simplify(const GiNaC::ex & e);
};



} // namespace SyFi

#endif 
