#include "FE.h"

#include <stdexcept>

using namespace std;

namespace SyFi {

StandardFE:: StandardFE() { 
    p = NULL; 
    order = -1; 
    description = "StandardFE"; 
}

StandardFE:: StandardFE(Polygon& p, int order) { 
    set_polygon(p); 
    set_order(order); 
    description = "StandardFE"; 
}



int StandardFE:: nbf() const {
    return Ns.size();  
}

std::string StandardFE:: str() {
  return description; 
}

void StandardFE:: compute_basis_functions() { 
    cout <<"StandardFE compute_basis_functions not implemented."<<endl; 
    cout <<"Use some derived class like e.g. LagrangeFE."<<endl; 
}

Polygon& StandardFE:: get_polygon() {
    if(!p)
    {
      throw std::runtime_error("No polygon has been set!");
    }
    return *p; 
}

void StandardFE:: set_polygon(Polygon& p_) {
    Ns.clear(); 
    dofs.clear(); 
    p = &p_; 
}


void StandardFE:: set_order(int order_) { 
    Ns.clear(); 
    dofs.clear(); 
    order = order_; 
}


GiNaC::ex StandardFE:: dof(int i) {
    if ( i < 0 || i > nbf()-1) {   
	    throw(std::out_of_range("The index is out of range!"));
    }
    return dofs[i]; 
}


GiNaC::ex StandardFE::N(int i) {  
    if ( i < 0 || i > nbf()-1) {   
	    throw(std::out_of_range("The index is out of range!"));
    }
    return Ns[i]; 
}

} // namespace SyFi 


