#ifndef FE_IS_INCLUDED
#define FE_IS_INCLUDED


#include <string>
#include "Polygon.h"


namespace SyFi {

class FE {
    public: 
        FE() {}
        virtual ~FE() {}

        virtual void set_polygon(Polygon& p) = 0;   // Set polygonal domain 
        virtual Polygon& get_polygon() = 0;         // Get polygonal domain 

        virtual void compute_basis_functions() = 0; // precompute basis functions
        virtual int nbf() const = 0;                // Number of basis functions/ degrees of freedom  
        virtual GiNaC::ex N(int i) = 0;             // The i'th basis function
        virtual GiNaC::ex dof(int i) = 0 ;          // The i'th degree of freedom 
        virtual std::string str() = 0; 
};


class StandardFE : public FE {
  protected: 
    GiNaC::exvector  Ns; 
    GiNaC::exvector  dofs; 
    Polygon* p; 
    int order; 
    std::string description; 

    public: 
        StandardFE(); 
        StandardFE(Polygon& p, int order);  
        virtual ~StandardFE() {}

        virtual void set_order(int order); 
        
        virtual void set_polygon(Polygon& p);  
        virtual Polygon& get_polygon();

        virtual void compute_basis_functions();  
        virtual int nbf() const; 
        virtual GiNaC::ex N(int i);  
        virtual GiNaC::ex dof(int i); 
        virtual std::string str(); 
}; 

}


#endif








