#include "P0.h"
#include "tools.h"

using std::cout;
using std::endl;

namespace SyFi {

P0::P0() : StandardFE() {
  description = "P0"; 
}

P0:: P0(Polygon& p, int order) : StandardFE (p,order) {
	compute_basis_functions(); 
}

void P0:: compute_basis_functions() {


    // remove previously computed basis functions and dofs
    Ns.clear(); 
    dofs.clear();

    if ( p == NULL ) {
        throw(std::logic_error("You need to set a polygon before the basisfunctions can be computed"));
    }

    // insert basis function
    Ns.insert(Ns.end(), GiNaC::numeric(1)); 

    // create and insert dof
    GiNaC::lst midpoint = GiNaC::lst(); 
    for (int d=0; d< p->vertex(1).nops(); d++) { 	   
        midpoint.append(GiNaC::numeric(0)); 
    }
    for (int i=1; i<= p->no_vertices(); i++) {   
        for (int d=0; d< p->vertex(i-1).nops(); d++) { 	   
            midpoint.let_op(d)  += p->vertex(i-1).op(d);
        }
    }

    for (int d=0; d< p->vertex(1).nops(); d++) { 	   
        midpoint.let_op(d)  = midpoint.op(d)/p->no_vertices(); 
    }

    dofs.insert(dofs.end(), midpoint); 

    description = istr("P0_"  , midpoint.nops()) + "D";  
}

// ------------VectorP0 --- 

VectorP0::VectorP0() : StandardFE() { 
  description = "VectorP0"; 
}

VectorP0::VectorP0(Polygon& p, int order, int size_) : StandardFE(p, order) { 
	size = size_ < 0 ? nsd: size_;
	compute_basis_functions(); 
} 




void VectorP0:: compute_basis_functions() {


    // remove previously computed basis functions and dofs
    Ns.clear(); 
    dofs.clear();


    if ( p == NULL ) {
        throw(std::logic_error("You need to set a polygon before the basisfunctions can be computed"));
    }




    if ( size == 0) {
        throw(std::logic_error("You need to set the size of the vector before the basisfunctions can be computed"));
    }


    P0 fe(*p); 
    GiNaC::lst zero_list; 
    for (int s=1; s<= size ; s++) {
        zero_list.append(0);  
    }

    for (int i=0; i< fe.nbf() ; i++) {
        for (int s=0; s< size ; s++) {
            GiNaC::lst Nis = zero_list;    
            Nis.let_op(s) = fe.N(i); 
            GiNaC::ex Nmat = GiNaC::matrix(size,1,Nis);
            Ns.insert(Ns.end(), Nmat);  

            GiNaC::lst dof = GiNaC::lst(fe.dof(i), s) ; 
            dofs.insert(dofs.end(), dof);  
        }
    }
    description = "Vector" + fe.str(); 
}


void VectorP0:: set_size(int size_) {
    size = size_; 
}

}

