#ifndef POLYGON_IS_INCLUDED
#define POLYGON_IS_INCLUDED

#include <string>
#include <ginac/ginac.h>

namespace SyFi {

enum  Repr_format { 
    SUBS_PERFORMED = 1, 
    SUBS_NOT_PERFORMED = 2
}; 

// TODO: No general quad support? Only straight rectangles here. Not enough for global quad elements like Tureks Q1-Q0?

// TODO: Can be const too:
// 	repr
// 	str
// 	integrate

// TODO: replace line() and triangle() with edge() and face() ?
// 	The problematic part here is returning pointers, leading to ugly memory leaks etc.
// 	Should be discussed first.
//virtual int no_edges() const = 0;
//virtual int no_faces() const = 0;
//virtual Line * edge(int i) const;
//virtual Polygon * face(int i) const;


class Triangle; 
class Line; 

class Polygon {
  protected: 
    Polygon(const std::string & subscript_="", int no_vert=0);

    std::string subscript; 
    GiNaC::exvector p; 

  public: 
    virtual ~Polygon() {}

    /* Return the topological dimension of the object. */
    virtual int no_space_dim() const = 0; 

    virtual int no_vertices() const; 
    virtual GiNaC::ex vertex(int i) const;

    virtual Line line(int i) const;
    virtual Triangle triangle(int i) const; 

    virtual GiNaC::ex repr(Repr_format format = SUBS_PERFORMED) = 0;
    virtual std::string str() = 0;

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED) = 0;
}; 


class Line : public Polygon  {
  protected:
    GiNaC::ex a_; 
    GiNaC::ex b_; 
  public:
    /* Constructing an empty object. */
    Line() {}
    /* x0_ and x1_ are points, of the type GiNaC::lst if dim>1 */
    Line(GiNaC::ex x0, GiNaC::ex x1, const std::string & subscript = "");
    virtual ~Line(){}

    virtual int no_space_dim() const; 

    GiNaC::ex a() const;
    GiNaC::ex b() const;

    virtual GiNaC::ex repr(Repr_format format = SUBS_PERFORMED);
    virtual GiNaC::ex repr(GiNaC::ex t, Repr_format format = SUBS_PERFORMED); 
    virtual std::string str(); 

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED);    
};


class ReferenceLine : public Line {
  public: 
    ReferenceLine(const std::string & subscript = ""); 
    virtual ~ReferenceLine(){}

    virtual GiNaC::ex repr(GiNaC::ex t, Repr_format format = SUBS_PERFORMED); 
    virtual std::string str(); 

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED); 
}; 


class Triangle : public Polygon {
  protected:
    Triangle(const std::string & subscript = "");
  public:
    Triangle(GiNaC::ex x0, GiNaC::ex x1, GiNaC::ex x1, const std::string & subscript = ""); 
    virtual ~Triangle(){}

    virtual int no_space_dim() const; 

    // TODO: implement this concept?
    //virtual Line * edge(int i) const;
    //virtual Triangle * face(int i) const;

    virtual Line line(int i) const; 

    virtual GiNaC::ex repr(Repr_format = SUBS_PERFORMED); 
    virtual std::string str(); 

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED); 
}; 


class ReferenceTriangle : public Triangle {
  public: 
    ReferenceTriangle(const std::string & subscript = ""); 
    virtual ~ReferenceTriangle(){}

    virtual std::string str(); 

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED);
}; 


class Rectangle : public Polygon {
  protected:
    Rectangle(const std::string & subscript = "");
  public: 
    Rectangle(GiNaC::ex p0, GiNaC::ex p1, const std::string & subscript = "");
    virtual ~Rectangle(){} 

    virtual int no_space_dim() const; 

    // TODO: implement this concept?
    //virtual Line * edge(int i) const;
    //virtual Rectangle * face(int i) const;

    virtual Line line(int i) const; 

    virtual GiNaC::ex repr(Repr_format format = SUBS_PERFORMED); 
    virtual std::string str(); 

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED);
}; 


class ReferenceRectangle : public Rectangle {
  public: 
    ReferenceRectangle(const std::string & subscript = "");
    virtual ~ReferenceRectangle(){} 

    virtual std::string str(); 
}; 


class Tetrahedron : public Polygon {
  public: 
    Tetrahedron(GiNaC::ex x0, GiNaC::ex x1, GiNaC::ex x1, GiNaC::ex x2, const std::string & subscript = ""); 
    virtual ~Tetrahedron(){}

    virtual int no_space_dim() const; 

    // TODO: implement this concept?
    //virtual Line * edge(int i) const;
    //virtual Triangle * face(int i) const;

    virtual Line line(int i) const; 
    virtual Triangle triangle(int i) const; 

    virtual GiNaC::ex repr(Repr_format format = SUBS_PERFORMED); 
    virtual std::string str(); 

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED);
}; 


class ReferenceTetrahedron : public Tetrahedron {
  public: 
    ReferenceTetrahedron(const std::string & subscript = ""); 
    virtual ~ReferenceTetrahedron(){}

    virtual std::string str(); 

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED);  
}; 


class Box: public Polygon {
  public: 
    Box(GiNaC::ex p0, GiNaC::ex p1, const std::string & subscript = "");
    Box(){}
    virtual ~Box(){} 

    virtual int no_space_dim() const; 

    // TODO: implement this concept?
    //virtual Line * edge(int i) const;
    //virtual Rectangle * face(int i) const;

    virtual Line line(int i) const; 

    virtual GiNaC::ex repr(Repr_format format = SUBS_PERFORMED); 
    virtual std::string str(); 

    virtual GiNaC::ex integrate(GiNaC::ex f, Repr_format format = SUBS_PERFORMED);
}; 


class ReferenceBox: public Box {
  public: 
    ReferenceBox(const std::string & subscript = "");
    virtual ~ReferenceBox(){} 

    virtual std::string str(); 
}; 



// ---- Some tools for Polygons 

// Factory functions for nsd-independent reference domains
Polygon *newReferenceSimplex(int nsd);
Polygon *newReferenceCube(int nsd);

// FIXME: change to barycenter(Triangle&)  
// FIXME:       and barycenter(Tetrahedron&)  
GiNaC::ex barycenter_line(GiNaC::ex p0, GiNaC::ex p1); 
GiNaC::ex barycenter_triangle(GiNaC::ex p0, GiNaC::ex p1, GiNaC::ex p2); 
GiNaC::ex barycenter_tetrahedron(GiNaC::ex p0, GiNaC::ex p1, GiNaC::ex p2, GiNaC::ex p3); 
GiNaC::lst bezier_ordinates(Triangle& triangle, int d);  
GiNaC::lst bezier_ordinates(Tetrahedron& tetrahedra, int d);  

// polynom of arbitrary order on a line, a triangle, 
// or a tetrahedron using the Bernstein basis 
GiNaC::ex bernstein(int order, Polygon& p, const std::string & a);  

// vector polynom of arbitrary order on a line, a triangle, 
// or a tetrahedron using the Bernstein basis 
GiNaC::lst bernsteinv(int no_fields, int order, Polygon& p, const std::string & a);  

GiNaC::lst normal(Triangle&, int i); 
GiNaC::lst normal(Tetrahedron&, int i); 

GiNaC::lst tangent(Triangle&, int i); 


}



#endif

