#include "symbol_factory.h" 
#include "diff_tools.h" 
#include "LagrangeFE.h"
#include "SpaceTimeElement.h"


namespace SyFi {


SpaceTimeDomain::SpaceTimeDomain(Line* time_line_, Polygon* polygon_) {
  time_line = time_line_; 
  polygon = polygon_; 
}

std::string SpaceTimeDomain::str() { 
  return "Time" + polygon->str(); 
}

int SpaceTimeDomain:: no_space_dim() const {
  return polygon->no_space_dim() +1; 
}

Line SpaceTimeDomain ::line(int i) const {
  //FIXME 
  // Could use the convention that the time line is the first line, the
  // next lines are the lines in the polygon 
  return Line(); 
}

GiNaC::ex SpaceTimeDomain:: repr(Repr_format format) {
  return GiNaC::lst(time_line->repr(t, format), polygon->repr(format)); 
}

GiNaC::ex SpaceTimeDomain::integrate(GiNaC::ex f,  Repr_format format) { 
  GiNaC::ex intf; 

  // integrate in space 
  intf = polygon->integrate(f, format);

  // integrate in time ((x,y,z) are now integrated away) 
  intf = intf.subs( t == x ); 
  intf = time_line->integrate(intf , format);   



  return intf; 

}

SpaceTimeElement:: SpaceTimeElement() : StandardFE() {
  description = "SpaceTimeElement"; 
}

SpaceTimeElement:: SpaceTimeElement(Line* time_line_, int order_, StandardFE* fe_) {
  time_line = time_line_;  
  order = order_; 
  fe = fe_; 
  compute_basis_functions(); 
}

void SpaceTimeElement:: set_time_domain(Line* line_) {
  time_line = line_; 
}

void SpaceTimeElement:: set_order_in_time(int order_) {
  order = order_; 
}

void SpaceTimeElement:: set_spatial_element(StandardFE* fe_) {
  fe = fe_; 
}

void SpaceTimeElement:: compute_basis_functions() {

    // remove previously computed basis functions and dofs
    Ns.clear(); 
    dofs.clear();

    if ( order < 1 ) {
        throw(std::logic_error("The elements must be of order 1 or higher."));
    }

    if ( time_line == NULL ) {
        throw(std::logic_error("You need to set a time domain before the basisfunctions can be computed"));
    }

    if ( fe == NULL ) {
        throw(std::logic_error("You need to set a spatial element before the basisfunctions can be computed"));
    }


    LagrangeFE time_element(*time_line, order); 

    for (int i = 0; i < time_element.nbf(); i++) { 
      GiNaC::ex Ni = time_element.N(i);  
      Ni = Ni.subs(x == t); 
      for (int j = 0; j < fe->nbf(); j++) { 
        GiNaC::ex Nj = fe->N(j);  
        GiNaC::ex N = Nj*Ni; 
        Ns.insert(Ns.end(), N); 
        dofs.insert(dofs.end(), GiNaC::lst(time_element.dof(i), fe->dof(j)));
      }
    }

    description = time_element.str() + "_" +  fe->str(); 
}




} // namespace SyFi  



